from random import randint

from .. import Provider as BaseProvider


class Provider(BaseProvider):
    # Source:
    # https://en.wikipedia.org/wiki/Thai_identity_card#Identification_number
    # Thai national identity number has 13 digits, in this format:
    # 1-2345-67890-12-3
    # Digit 1: Person category
    # Digits 2-5: Province and amphoe code of registrar's office (ISO 3166-2)
    # Digits 6-12: Birth certificate number
    # Digit 13: Checksum

    def ssn(self) -> str:
        """
        Thai national ID
        """
        category = randint(1, 8)
        province = randint(10, 96)
        amphoe = 0
        if province == 10:  # Bangkok
            amphoe = randint(1, 50)  # Bangkok has district number up to 50
        else:
            amphoe = randint(1, 20)  # Provinces outside Bangkok has 20 or less
        birth_book = randint(1, 99999)
        birth_sheet = randint(1, 99)

        digits = f"{category:01d}{province:02d}{amphoe:02d}{birth_book:05d}{birth_sheet:02d}"
        checksum = (
            (int(digits[0]) * 13)
            + (int(digits[1]) * 12)
            + (int(digits[2]) * 11)
            + (int(digits[3]) * 10)
            + (int(digits[4]) * 9)
            + (int(digits[5]) * 8)
            + (int(digits[6]) * 7)
            + (int(digits[7]) * 6)
            + (int(digits[8]) * 5)
            + (int(digits[9]) * 4)
            + (int(digits[10]) * 3)
            + (int(digits[11]) * 2)
        )
        checksum = checksum % 11
        checksum = 11 - checksum
        if checksum > 9:
            checksum = checksum - 10

        nat_id = f"{category:01d}-{province:02d}{amphoe:02d}-{birth_book:05d}-{birth_sheet:02d}-{checksum:01d}"

        return nat_id

    def vat_id(self) -> str:
        """
        Personal VAT ID is the same as national ID
        (Corporate VAT ID is different)
        """
        return self.ssn()



from collections import OrderedDict
from typing import Dict, Sequence

from .. import Provider as PersonProvider


# See transliteration table https://en.wikipedia.org/wiki/Romanization_of_Russian#Transliteration_table
def translit(text: str) -> str:
    translit_dict: Dict[str, str] = {
        "а": "a",
        "б": "b",
        "в": "v",
        "г": "g",
        "д": "d",
        "е": "e",
        "ё": "e",
        "ж": "zh",
        "з": "z",
        "и": "i",
        "й": "y",
        "к": "k",
        "л": "l",
        "м": "m",
        "н": "n",
        "о": "o",
        "п": "p",
        "р": "r",
        "с": "s",
        "т": "t",
        "у": "u",
        "ф": "f",
        "х": "kh",
        "ц": "ts",
        "ч": "ch",
        "ш": "sh",
        "щ": "shch",
        "ъ": "",
        "ы": "y",
        "ь": "",
        "э": "e",
        "ю": "yu",
        "я": "ya",
        "А": "A",
        "Б": "B",
        "В": "V",
        "Г": "G",
        "Д": "D",
        "Е": "Ye",
        "Ë": "E",
        "Ж": "Zh",
        "З": "Z",
        "И": "I",
        "Й": "Y",
        "К": "K",
        "Л": "L",
        "М": "M",
        "Н": "N",
        "О": "O",
        "П": "P",
        "Р": "R",
        "С": "S",
        "Т": "T",
        "У": "U",
        "Ф": "F",
        "Х": "Kh",
        "Ц": "Ts",
        "Ч": "Ch",
        "Ш": "Sh",
        "Щ": "Shch",
        "Ы": "Y",
        "Э": "E",
        "Ю": "Yu",
        "Я": "Ya",
    }
    for letter in text:
        if letter.isalpha():
            text = text.replace(letter, translit_dict[letter])
    return text


class Provider(PersonProvider):
    formats_male: Dict[str, float] = OrderedDict(
        (
            ("{{last_name_male}} {{first_name_male}} {{middle_name_male}}", 0.49),
            ("{{first_name_male}} {{middle_name_male}} {{last_name_male}}", 0.49),
            (
                "{{prefix_male}} {{last_name_male}} {{first_name_male}} {{middle_name_male}}",
                0.02,
            ),
        )
    )

    formats_female: Dict[str, float] = OrderedDict(
        (
            ("{{last_name_female}} {{first_name_female}} {{middle_name_female}}", 0.49),
            ("{{first_name_female}} {{middle_name_female}} {{last_name_female}}", 0.49),
            (
                "{{prefix_female}} {{last_name_female}} {{first_name_female}} {{middle_name_female}}",
                0.02,
            ),
        )
    )

    # Using random_element's dictionary weighting means that the
    #     formats = formats_male + formats_female
    # has to be replaced with something dict and python 2.x compatible

    formats: Dict[str, float] = formats_male.copy()
    formats.update(formats_female)

    first_names_male = (
        "Август",
        "Авдей",
        "Аверкий",
        "Аверьян",
        "Авксентий",
        "Автоном",
        "Агап",
        "Агафон",
        "Аггей",
        "Адам",
        "Адриан",
        "Азарий",
        "Аким",
        "Александр",
        "Алексей",
        "Амвросий",
        "Амос",
        "Ананий",
        "Анатолий",
        "Андрей",
        "Андрон",
        "Андроник",
        "Аникей",
        "Аникита",
        "Анисим",
        "Антип",
        "Антонин",
        "Аполлинарий",
        "Аполлон",
        "Арефий",
        "Аристарх",
        "Аркадий",
        "Арсений",
        "Артемий",
        "Артем",
        "Архип",
        "Аскольд",
        "Афанасий",
        "Афиноген",
        "Бажен",
        "Богдан",
        "Болеслав",
        "Борис",
        "Борислав",
        "Боян",
        "Бронислав",
        "Будимир",
        "Вадим",
        "Валентин",
        "Валерий",
        "Валерьян",
        "Варлаам",
        "Варфоломей",
        "Василий",
        "Вацлав",
        "Велимир",
        "Венедикт",
        "Вениамин",
        "Викентий",
        "Виктор",
        "Викторин",
        "Виссарион",
        "Виталий",
        "Владилен",
        "Владлен",
        "Владимир",
        "Владислав",
        "Влас",
        "Всеволод",
        "Всемил",
        "Всеслав",
        "Вышеслав",
        "Вячеслав",
        "Гаврила",
        "Галактион",
        "Гедеон",
        "Геннадий",
        "Георгий",
        "Герасим",
        "Герман",
        "Глеб",
        "Гордей",
        "Гостомысл",
        "Гремислав",
        "Григорий",
        "Гурий",
        "Давыд",
        "Данила",
        "Дементий",
        "Демид",
        "Демьян",
        "Денис",
        "Дмитрий",
        "Добромысл",
        "Доброслав",
        "Дорофей",
        "Евгений",
        "Евграф",
        "Евдоким",
        "Евлампий",
        "Евсей",
        "Евстафий",
        "Евстигней",
        "Егор",
        "Елизар",
        "Елисей",
        "Емельян",
        "Епифан",
        "Еремей",
        "Ермил",
        "Ермолай",
        "Ерофей",
        "Ефим",
        "Ефрем",
        "Захар",
        "Зиновий",
        "Зосима",
        "Иван",
        "Игнатий",
        "Игорь",
        "Измаил",
        "Изот",
        "Изяслав",
        "Иларион",
        "Илья",
        "Иннокентий",
        "Иосиф",
        "Ипат",
        "Ипатий",
        "Ипполит",
        "Ираклий",
        "Исай",
        "Исидор",
        "Казимир",
        "Каллистрат",
        "Капитон",
        "Карл",
        "Карп",
        "Касьян",
        "Ким",
        "Кир",
        "Кирилл",
        "Клавдий",
        "Климент",
        "Кондрат",
        "Кондратий",
        "Конон",
        "Константин",
        "Корнил",
        "Кузьма",
        "Куприян",
        "Лавр",
        "Лаврентий",
        "Ладимир",
        "Ладислав",
        "Лазарь",
        "Лев",
        "Леон",
        "Леонид",
        "Леонтий",
        "Лонгин",
        "Лука",
        "Лукьян",
        "Лучезар",
        "Любим",
        "Любомир",
        "Любосмысл",
        "Макар",
        "Максим",
        "Максимильян",
        "Мариан",
        "Марк",
        "Мартын",
        "Мартьян",
        "Матвей",
        "Мефодий",
        "Мечислав",
        "Милан",
        "Милен",
        "Милий",
        "Милован",
        "Мина",
        "Мир",
        "Мирон",
        "Мирослав",
        "Митофан",
        "Михаил",
        "Михей",
        "Модест",
        "Моисей",
        "Мокей",
        "Мстислав",
        "Назар",
        "Наркис",
        "Натан",
        "Наум",
        "Нестор",
        "Никандр",
        "Никанор",
        "Никита",
        "Никифор",
        "Никодим",
        "Николай",
        "Никон",
        "Нифонт",
        "Олег",
        "Олимпий",
        "Онуфрий",
        "Орест",
        "Осип",
        "Остап",
        "Остромир",
        "Павел",
        "Панкратий",
        "Панкрат",
        "Пантелеймон",
        "Панфил",
        "Парамон",
        "Парфен",
        "Пахом",
        "Петр",
        "Пимен",
        "Платон",
        "Поликарп",
        "Порфирий",
        "Потап",
        "Пров",
        "Прокл",
        "Прокофий",
        "Прохор",
        "Радим",
        "Радислав",
        "Радован",
        "Ратибор",
        "Ратмир",
        "Родион",
        "Роман",
        "Ростислав",
        "Рубен",
        "Руслан",
        "Рюрик",
        "Савва",
        "Савватий",
        "Савелий",
        "Самсон",
        "Самуил",
        "Светозар",
        "Святополк",
        "Святослав",
        "Севастьян",
        "Селиван",
        "Селиверст",
        "Семен",
        "Серафим",
        "Сергей",
        "Сигизмунд",
        "Сидор",
        "Сила",
        "Силантий",
        "Сильвестр",
        "Симон",
        "Сократ",
        "Соломон",
        "Софон",
        "Софрон",
        "Спартак",
        "Спиридон",
        "Станимир",
        "Станислав",
        "Степан",
        "Стоян",
        "Тарас",
        "Твердислав",
        "Творимир",
        "Терентий",
        "Тимофей",
        "Тимур",
        "Тит",
        "Тихон",
        "Трифон",
        "Трофим",
        "Ульян",
        "Устин",
        "Фадей",
        "Федор",
        "Федосий",
        "Федот",
        "Феликс",
        "Феоктист",
        "Феофан",
        "Ферапонт",
        "Филарет",
        "Филимон",
        "Филипп",
        "Фирс",
        "Флорентин",
        "Фока",
        "Фома",
        "Фортунат",
        "Фотий",
        "Фрол",
        "Харитон",
        "Харлампий",
        "Христофор",
        "Чеслав",
        "Эдуард",
        "Эммануил",
        "Эмиль",
        "Эраст",
        "Эрнест",
        "Эрнст",
        "Ювеналий",
        "Юлиан",
        "Юлий",
        "Юрий",
        "Яков",
        "Ян",
        "Якуб",
        "Януарий",
        "Ярополк",
        "Ярослав",
    )

    first_names_female = (
        "Агата",
        "Агафья",
        "Акулина",
        "Алевтина",
        "Александра",
        "Алина",
        "Алла",
        "Анастасия",
        "Ангелина",
        "Анжела",
        "Анжелика",
        "Анна",
        "Антонина",
        "Валентина",
        "Валерия",
        "Варвара",
        "Василиса",
        "Вера",
        "Вероника",
        "Виктория",
        "Галина",
        "Глафира",
        "Дарья",
        "Евгения",
        "Евдокия",
        "Евпраксия",
        "Евфросиния",
        "Екатерина",
        "Елена",
        "Елизавета",
        "Жанна",
        "Зинаида",
        "Зоя",
        "Иванна",
        "Ираида",
        "Ирина",
        "Ия",
        "Кира",
        "Клавдия",
        "Ксения",
        "Лариса",
        "Лидия",
        "Лора",
        "Лукия",
        "Любовь",
        "Людмила",
        "Майя",
        "Маргарита",
        "Марина",
        "Мария",
        "Марфа",
        "Милица",
        "Надежда",
        "Наина",
        "Наталья",
        "Нина",
        "Нинель",
        "Нонна",
        "Оксана",
        "Октябрина",
        "Олимпиада",
        "Ольга",
        "Пелагея",
        "Полина",
        "Прасковья",
        "Раиса",
        "Регина",
        "Светлана",
        "Синклитикия",
        "София",
        "Таисия",
        "Тамара",
        "Татьяна",
        "Ульяна",
        "Фаина",
        "Феврония",
        "Фёкла",
        "Элеонора",
        "Эмилия",
        "Юлия",
    )

    first_names = first_names_male + first_names_female

    last_names_male = (
        "Смирнов",
        "Иванов",
        "Кузнецов",
        "Попов",
        "Соколов",
        "Лебедев",
        "Козлов",
        "Новиков",
        "Морозов",
        "Петров",
        "Волков",
        "Соловьев",
        "Васильев",
        "Зайцев",
        "Павлов",
        "Семенов",
        "Голубев",
        "Виноградов",
        "Богданов",
        "Воробьев",
        "Федоров",
        "Михайлов",
        "Беляев",
        "Тарасов",
        "Белов",
        "Комаров",
        "Орлов",
        "Киселев",
        "Макаров",
        "Андреев",
        "Ковалев",
        "Ильин",
        "Гусев",
        "Титов",
        "Кузьмин",
        "Кудрявцев",
        "Баранов",
        "Куликов",
        "Алексеев",
        "Степанов",
        "Яковлев",
        "Сорокин",
        "Сергеев",
        "Романов",
        "Захаров",
        "Борисов",
        "Королев",
        "Герасимов",
        "Пономарев",
        "Григорьев",
        "Лазарев",
        "Медведев",
        "Ершов",
        "Никитин",
        "Соболев",
        "Рябов",
        "Поляков",
        "Цветков",
        "Данилов",
        "Жуков",
        "Фролов",
        "Журавлев",
        "Николаев",
        "Крылов",
        "Максимов",
        "Сидоров",
        "Осипов",
        "Белоусов",
        "Федотов",
        "Дорофеев",
        "Егоров",
        "Матвеев",
        "Бобров",
        "Дмитриев",
        "Калинин",
        "Анисимов",
        "Петухов",
        "Антонов",
        "Тимофеев",
        "Никифоров",
        "Веселов",
        "Филиппов",
        "Марков",
        "Большаков",
        "Суханов",
        "Миронов",
        "Ширяев",
        "Александров",
        "Коновалов",
        "Шестаков",
        "Казаков",
        "Ефимов",
        "Денисов",
        "Громов",
        "Фомин",
        "Давыдов",
        "Мельников",
        "Щербаков",
        "Блинов",
        "Колесников",
        "Карпов",
        "Афанасьев",
        "Власов",
        "Маслов",
        "Исаков",
        "Тихонов",
        "Аксенов",
        "Гаврилов",
        "Родионов",
        "Котов",
        "Горбунов",
        "Кудряшов",
        "Быков",
        "Зуев",
        "Третьяков",
        "Савельев",
        "Панов",
        "Рыбаков",
        "Суворов",
        "Абрамов",
        "Воронов",
        "Мухин",
        "Архипов",
        "Трофимов",
        "Мартынов",
        "Емельянов",
        "Горшков",
        "Чернов",
        "Овчинников",
        "Селезнев",
        "Панфилов",
        "Копылов",
        "Михеев",
        "Галкин",
        "Назаров",
        "Лобанов",
        "Лукин",
        "Беляков",
        "Потапов",
        "Некрасов",
        "Хохлов",
        "Жданов",
        "Наумов",
        "Шилов",
        "Воронцов",
        "Ермаков",
        "Дроздов",
        "Игнатьев",
        "Савин",
        "Логинов",
        "Сафонов",
        "Капустин",
        "Кириллов",
        "Моисеев",
        "Елисеев",
        "Кошелев",
        "Костин",
        "Горбачев",
        "Орехов",
        "Ефремов",
        "Исаев",
        "Евдокимов",
        "Калашников",
        "Кабанов",
        "Носков",
        "Юдин",
        "Кулагин",
        "Лапин",
        "Прохоров",
        "Нестеров",
        "Харитонов",
        "Агафонов",
        "Муравьев",
        "Ларионов",
        "Федосеев",
        "Зимин",
        "Пахомов",
        "Шубин",
        "Игнатов",
        "Филатов",
        "Крюков",
        "Рогов",
        "Кулаков",
        "Терентьев",
        "Молчанов",
        "Владимиров",
        "Артемьев",
        "Гурьев",
        "Зиновьев",
        "Гришин",
        "Кононов",
        "Дементьев",
        "Ситников",
        "Симонов",
        "Мишин",
        "Фадеев",
        "Комиссаров",
        "Мамонтов",
        "Носов",
        "Гуляев",
        "Шаров",
        "Устинов",
        "Вишняков",
        "Евсеев",
        "Лаврентьев",
        "Брагин",
        "Константинов",
        "Корнилов",
        "Авдеев",
        "Зыков",
        "Бирюков",
        "Шарапов",
        "Никонов",
        "Щукин",
        "Дьячков",
        "Одинцов",
        "Сазонов",
        "Якушев",
        "Красильников",
        "Гордеев",
        "Самойлов",
        "Князев",
        "Беспалов",
        "Уваров",
        "Шашков",
        "Бобылев",
        "Доронин",
        "Белозеров",
        "Рожков",
        "Самсонов",
        "Мясников",
        "Лихачев",
        "Буров",
        "Сысоев",
        "Фомичев",
        "Русаков",
        "Стрелков",
        "Гущин",
        "Тетерин",
        "Колобов",
        "Субботин",
        "Фокин",
        "Блохин",
        "Селиверстов",
        "Пестов",
        "Кондратьев",
        "Силин",
        "Меркушев",
        "Лыткин",
        "Туров",
    )

    last_names_female = (
        "Смирнова",
        "Иванова",
        "Кузнецова",
        "Попова",
        "Соколова",
        "Лебедева",
        "Козлова",
        "Новикова",
        "Морозова",
        "Петрова",
        "Волкова",
        "Соловьева",
        "Васильева",
        "Зайцева",
        "Павлова",
        "Семенова",
        "Голубева",
        "Виноградова",
        "Богданова",
        "Воробьева",
        "Федорова",
        "Михайлова",
        "Беляева",
        "Тарасова",
        "Белова",
        "Комарова",
        "Орлова",
        "Киселева",
        "Макарова",
        "Андреева",
        "Ковалева",
        "Ильина",
        "Гусева",
        "Титова",
        "Кузьмина",
        "Кудрявцева",
        "Баранова",
        "Куликова",
        "Алексеева",
        "Степанова",
        "Яковлева",
        "Сорокина",
        "Сергеева",
        "Романова",
        "Захарова",
        "Борисова",
        "Королева",
        "Герасимова",
        "Пономарева",
        "Григорьева",
        "Лазарева",
        "Медведева",
        "Ершова",
        "Никитина",
        "Соболева",
        "Рябова",
        "Полякова",
        "Цветкова",
        "Данилова",
        "Жукова",
        "Фролова",
        "Журавлева",
        "Николаева",
        "Крылова",
        "Максимова",
        "Сидорова",
        "Осипова",
        "Белоусова",
        "Федотова",
        "Дорофеева",
        "Егорова",
        "Матвеева",
        "Боброва",
        "Дмитриева",
        "Калинина",
        "Анисимова",
        "Петухова",
        "Антонова",
        "Тимофеева",
        "Никифорова",
        "Веселова",
        "Филиппова",
        "Маркова",
        "Большакова",
        "Суханова",
        "Миронова",
        "Ширяева",
        "Александрова",
        "Коновалова",
        "Шестакова",
        "Казакова",
        "Ефимова",
        "Денисова",
        "Громова",
        "Фомина",
        "Давыдова",
        "Мельникова",
        "Щербакова",
        "Блинова",
        "Колесникова",
        "Карпова",
        "Афанасьева",
        "Власова",
        "Маслова",
        "Исакова",
        "Тихонова",
        "Аксенова",
        "Гаврилова",
        "Родионова",
        "Котова",
        "Горбунова",
        "Кудряшова",
        "Быкова",
        "Зуева",
        "Третьякова",
        "Савельева",
        "Панова",
        "Рыбакова",
        "Суворова",
        "Абрамова",
        "Воронова",
        "Мухина",
        "Архипова",
        "Трофимова",
        "Мартынова",
        "Емельянова",
        "Горшкова",
        "Чернова",
        "Овчинникова",
        "Селезнева",
        "Панфилова",
        "Копылова",
        "Михеева",
        "Галкина",
        "Назарова",
        "Лобанова",
        "Лукина",
        "Белякова",
        "Потапова",
        "Некрасова",
        "Хохлова",
        "Жданова",
        "Наумова",
        "Шилова",
        "Воронцова",
        "Ермакова",
        "Дроздова",
        "Игнатьева",
        "Савина",
        "Логинова",
        "Сафонова",
        "Капустина",
        "Кириллова",
        "Моисеева",
        "Елисеева",
        "Кошелева",
        "Костина",
        "Горбачева",
        "Орехова",
        "Ефремова",
        "Исаева",
        "Евдокимова",
        "Калашникова",
        "Кабанова",
        "Носкова",
        "Юдина",
        "Кулагина",
        "Лапина",
        "Прохорова",
        "Нестерова",
        "Харитонова",
        "Агафонова",
        "Муравьева",
        "Ларионова",
        "Федосеева",
        "Зимина",
        "Пахомова",
        "Шубина",
        "Игнатова",
        "Филатова",
        "Крюкова",
        "Рогова",
        "Кулакова",
        "Терентьева",
        "Молчанова",
        "Владимирова",
        "Артемьева",
        "Гурьева",
        "Зиновьева",
        "Гришина",
        "Кононова",
        "Дементьева",
        "Ситникова",
        "Симонова",
        "Мишина",
        "Фадеева",
        "Комиссарова",
        "Мамонтова",
        "Носова",
        "Гуляева",
        "Шарова",
        "Устинова",
        "Вишнякова",
        "Евсеева",
        "Лаврентьева",
        "Брагина",
        "Константинова",
        "Корнилова",
        "Авдеева",
        "Зыкова",
        "Бирюкова",
        "Шарапова",
        "Никонова",
        "Щукина",
        "Дьячкова",
        "Одинцова",
        "Сазонова",
        "Якушева",
        "Красильникова",
        "Гордеева",
        "Самойлова",
        "Князева",
        "Беспалова",
        "Уварова",
        "Шашкова",
        "Бобылева",
        "Доронина",
        "Белозерова",
        "Рожкова",
        "Самсонова",
        "Мясникова",
        "Лихачева",
        "Бурова",
        "Сысоева",
        "Фомичева",
        "Русакова",
        "Стрелкова",
        "Гущина",
        "Тетерина",
        "Колобова",
        "Субботина",
        "Фокина",
        "Блохина",
        "Селиверстова",
        "Пестова",
        "Кондратьева",
        "Силина",
        "Меркушева",
        "Лыткина",
        "Турова",
    )

    last_names = last_names_male + last_names_female

    middle_names_male = (
        "Ааронович",
        "Абрамович",
        "Августович",
        "Авдеевич",
        "Аверьянович",
        "Адамович",
        "Адрианович",
        "Аксёнович",
        "Александрович",
        "Алексеевич",
        "Анатольевич",
        "Андреевич",
        "Анисимович",
        "Антипович",
        "Антонович",
        "Ануфриевич",
        "Арсенович",
        "Арсеньевич",
        "Артёмович",
        "Артемьевич",
        "Артурович",
        "Архипович",
        "Афанасьевич",
        "Бенедиктович",
        "Богданович",
        "Бориславович",
        "Бориславович",
        "Борисович",
        "Брониславович",
        "Валентинович",
        "Валерианович",
        "Валерьевич",
        "Валерьянович",
        "Васильевич",
        "Венедиктович",
        "Викентьевич",
        "Викторович",
        "Виленович",
        "Вилорович",
        "Витальевич",
        "Владиленович",
        "Владиславович",
        "Владленович",
        "Власович",
        "Всеволодович",
        "Вячеславович",
        "Гавриилович",
        "Гаврилович",
        "Геннадиевич",
        "Георгиевич",
        "Герасимович",
        "Германович",
        "Гертрудович",
        "Глебович",
        "Гордеевич",
        "Григорьевич",
        "Гурьевич",
        "Давидович",
        "Давыдович",
        "Даниилович",
        "Данилович",
        "Демидович",
        "Демьянович",
        "Денисович",
        "Димитриевич",
        "Дмитриевич",
        "Дорофеевич",
        "Евсеевич",
        "Евстигнеевич",
        "Егорович",
        "Елизарович",
        "Елисеевич",
        "Еремеевич",
        "Ермилович",
        "Ермолаевич",
        "Ерофеевич",
        "Ефимович",
        "Ефимьевич",
        "Ефремович",
        "Ефстафьевич",
        "Жанович",
        "Жоресович",
        "Захарьевич",
        "Зиновьевич",
        "Игнатович",
        "Игнатьевич",
        "Игоревич",
        "Измаилович",
        "Изотович",
        "Иларионович",
        "Ильич",
        "Ильясович",
        "Иосипович",
        "Иосифович",
        "Исидорович",
        "Марсович",
        "Матвеевич",
        "Тарасович",
        "Теймуразович",
        "Терентьевич",
        "Тимурович",
        "Тихонович",
        "Трифонович",
        "Трофимович",
        "Устинович",
        "Фадеевич",
        "Фёдорович",
        "Федосеевич",
        "Федосьевич",
        "Федотович",
        "Феликсович",
        "Феодосьевич",
        "Феоктистович",
        "Феофанович",
        "Филатович",
        "Филимонович",
        "Филиппович",
        "Фокич",
        "Фомич",
        "Фролович",
        "Харитонович",
        "Харламович",
        "Харлампович",
        "Харлампьевич",
        "Чеславович",
        "Эдгардович",
        "Эдгарович",
        "Эдуардович",
        "Юлианович",
        "Юльевич",
        "Яковлевич",
        "Якубович",
        "Ярославович",
    )

    middle_names_female = (
        "Александровна",
        "Андреевна",
        "Архиповна",
        "Алексеевна",
        "Антоновна",
        "Аскольдовна",
        "Альбертовна",
        "Аркадьевна",
        "Афанасьевна",
        "Анатольевна",
        "Артемовна",
        "Богдановна",
        "Болеславовна",
        "Борисовна",
        "Вадимовна",
        "Васильевна",
        "Владимировна",
        "Валентиновна",
        "Вениаминовна",
        "Владиславовна",
        "Валериевна",
        "Викторовна",
        "Вячеславовна",
        "Геннадиевна",
        "Георгиевна",
        "Геннадьевна",
        "Григорьевна",
        "Даниловна",
        "Дмитриевна",
        "Евгеньевна",
        "Егоровна",
        "Ефимовна",
        "Ждановна",
        "Захаровна",
        "Ивановна",
        "Игоревна",
        "Ильинична",
        "Кирилловна",
        "Кузьминична",
        "Константиновна",
        "Кузьминична",
        "Леонидовна",
        "Леоновна",
        "Львовна",
        "Макаровна",
        "Матвеевна",
        "Михайловна",
        "Максимовна",
        "Мироновна",
        "Натановна",
        "Никифоровна",
        "Ниловна",
        "Наумовна",
        "Николаевна",
        "Олеговна",
        "Оскаровна",
        "Павловна",
        "Петровна",
        "Робертовна",
        "Рубеновна",
        "Руслановна",
        "Романовна",
        "Рудольфовна",
        "Святославовна",
        "Сергеевна",
        "Степановна",
        "Семеновна",
        "Станиславовна",
        "Тарасовна",
        "Тимофеевна",
        "Тимуровна",
        "Федоровна",
        "Феликсовна",
        "Филипповна",
        "Харитоновна",
        "Эдуардовна",
        "Эльдаровна",
        "Юльевна",
        "Юрьевна",
        "Яковлевна",
    )

    middle_names = middle_names_male + middle_names_female

    language_names = (
        "Афарский",
        "Абхазский",
        "Авестийский",
        "Африкаанс",
        "Акан",
        "Амхарский",
        "Арагонский",
        "Арабский",
        "Ассамский",
        "Аварский",
        "Аймарский",
        "Азербайджанский",
        "Башкирский",
        "Белорусский",
        "Болгарский",
        "Бислама",
        "Бенгальский",
        "Тибетский",
        "Бретонский",
        "Боснийский",
        "Каталанский",
        "Чеченский",
        "Чаморро",
        "Корсиканский",
        "Кри",
        "Чешский",
        "Чувашский",
        "Валлийский",
        "Датский",
        "Немецкий",
        "Греческий",
        "Английский",
        "Эсперанто",
        "Испанский",
        "Эстонский",
        "Персидский",
        "Финский",
        "Фиджийский",
        "Фарси",
        "Французский",
        "Ирландский",
        "Гэльский",
        "Галийский",
        "Иврит",
        "Хинди",
        "Хорватский",
        "Гавайский",
        "Болгарский",
        "Армянский",
        "Индонезийский",
        "Исландский",
        "Итальянский",
        "Японский",
        "Яванский",
        "Грузинский",
        "Казахский",
        "Корейский",
        "Кашмири",
        "Курдский",
        "Коми",
        "Киргизский",
        "Латинский",
        "Люксембургский",
        "Лимбургский",
        "Лингала",
        "Лаосский",
        "Литовский",
        "Латвийский",
        "Малагасийский",
        "Маршалльский",
        "Маори",
        "Македонский",
        "Малаялам",
        "Монгольский",
        "Маратхи",
        "Малайский",
        "Мальтийский",
        "Непальский",
        "Нидерландский",
        "Норвежский",
        "Навахо",
        "Оромо",
        "Ория",
        "Осетинский",
        "Пали",
        "Польский",
        "Пуштунский",
        "Португальский",
        "Романшский",
        "Румынский",
        "Русский",
        "Киньяруанда",
        "Санскрит",
        "Сардинский",
        "Санго",
        "Сингальский",
        "Словацкий",
        "Словенский",
        "Самоанский",
        "Сомалийский",
        "Албанский",
        "Сербский",
        "Сунданский",
        "Шведский",
        "Суахили",
        "Тамильский",
        "Телугу",
        "Таджикский",
        "Тайский",
        "Тигринья",
        "Туркменский",
        "Тагальский",
        "Тсвана",
        "Тонга",
        "Турецкий",
        "Тсонга",
        "Татарский",
        "Таитянский",
        "Уйгурский",
        "Украинский",
        "Урду",
        "Узбекский",
        "Венда",
        "Вьетнамский",
        "Идиш",
        "Йоруба",
        "Китайский",
        "Зулу",
    )

    prefixes_male: Sequence[str] = ("г-н", "тов.")

    prefixes_female: Sequence[str] = ("г-жа", "тов.")

    def middle_name(self) -> str:
        return self.random_element(self.middle_names)

    def middle_name_male(self) -> str:
        return self.random_element(self.middle_names_male)

    def middle_name_female(self) -> str:
        return self.random_element(self.middle_names_female)



from .. import Provider as PersonProvider


class Provider(PersonProvider):
    formats = (
        "{{first_name_male}} {{last_name}}",
        "{{first_name_male}} {{last_name}}",
        "{{first_name_male}} {{last_name}}",
        "{{first_name_male}} {{last_name}}",
        "{{first_name_male}} {{last_name}}-{{last_name}}",
        "{{first_name_female}} {{last_name}}",
        "{{first_name_female}} {{last_name}}",
        "{{first_name_female}} {{last_name}}",
        "{{first_name_female}} {{last_name}}",
        "{{first_name_female}} {{last_name}}-{{last_name}}",
        "{{prefix_male}} {{first_name_male}} {{last_name}}",
        "{{prefix_female}} {{first_name_female}} {{last_name}}",
        "{{prefix_male}} {{first_name_male}} {{last_name}}",
        "{{prefix_female}} {{first_name_female}} {{last_name}}",
    )

    first_names_male = (
        "Adam",
        "Albert",
        "Aksel",
        "Alex",
        "Alexander",
        "Alf",
        "Allan",
        "Alvin",
        "Anders",
        "André",
        "Andreas",
        "Anton",
        "Arne",
        "Asger",
        "ugust",
        "Benjamin",
        "Benny",
        "Bent",
        "Bertil",
        "Bertram",
        "Birger",
        "Bjarne",
        "Bo",
        "Bob",
        "Bobby",
        "Boe",
        "Boris",
        "Borris",
        "Brian",
        "Bruno",
        "Bøje",
        "Børge",
        "Carl",
        "Carlo",
        "Carsten",
        "Casper",
        "Christian",
        "Christoffer",
        "Christopher",
        "Claus",
        "Clavs",
        "Curt",
        "Dan",
        "Daniel",
        "Danny",
        "David",
        "Dennis",
        "Ebbe",
        "Einar",
        "Einer",
        "Elias",
        "Emil",
        "Eric",
        "Erik",
        "Erling",
        "Ernst",
        "Esben",
        "Finn",
        "Flemming",
        "Frank",
        "Frans",
        "Freddy",
        "Frede",
        "Frederik",
        "Frode",
        "Georg",
        "George",
        "Gert",
        "Gorm",
        "Gunnar",
        "Gunner",
        "Gustav",
        "Hans",
        "Helge",
        "Henrik",
        "Henry",
        "Herbert",
        "Herman",
        "Hjalte",
        "Holger",
        "Hugo",
        "Ib",
        "Ivan",
        "Iver",
        "Jack",
        "Jacob",
        "Jakob",
        "James",
        "Jan",
        "Jano",
        "Jarl",
        "Jean",
        "Jens",
        "Jeppe",
        "Jesper",
        "Jim",
        "Jimmy",
        "Joachim",
        "Joakim",
        "Johan",
        "Johannes",
        "John",
        "Johnnie",
        "Johnny",
        "Jon",
        "Jonas",
        "Jonathan",
        "Julius",
        "Jørgen",
        "Karl",
        "Karlo",
        "Karsten",
        "Kaspar",
        "Kasper",
        "Keld",
        "Ken",
        "Kenn",
        "Kenneth",
        "Kenny",
        "Kent",
        "Kim",
        "Kjeld",
        "Klaus",
        "Klavs",
        "Kristian",
        "Kurt",
        "Kåre",
        "Lars",
        "Lasse",
        "Laurits",
        "Laus",
        "Laust",
        "Leif",
        "Lennarth",
        "Lucas",
        "Ludvig",
        "Mads",
        "Magnus",
        "Malthe",
        "Marcus",
        "Marius",
        "Mark",
        "Martin",
        "Mathias",
        "Matthias",
        "Michael",
        "Mik",
        "Mikael",
        "Mike",
        "Mikkel",
        "Mogens",
        "Morten",
        "Nick",
        "Nicklas",
        "Nicolai",
        "Nicolaj",
        "Niels",
        "Nikolai",
        "Nikolaj",
        "Nils",
        "Noah",
        "Ole",
        "Olfert",
        "Oliver",
        "Oscar",
        "Oskar",
        "Osvald",
        "Otto",
        "Ove",
        "Palle",
        "Patrick",
        "Paw",
        "Peder",
        "Per",
        "Pete",
        "Peter",
        "Paul",
        "Philip",
        "Poul",
        "Preben",
        "Ragnar",
        "Ragner",
        "Rasmus",
        "René",
        "Richard",
        "Richardt",
        "Robert",
        "Robin",
        "Rolf",
        "Ron",
        "Ronni",
        "Ronnie",
        "Ronny",
        "Ruben",
        "Rune",
        "Sam",
        "Sebastian",
        "Silas",
        "Simon",
        "Simon",
        "Sonny",
        "Steen",
        "Stefan",
        "Sten",
        "Stephan",
        "Steve",
        "Steven",
        "Stig",
        "Svenning",
        "Søren",
        "Tage",
        "Tejs",
        "Thomas",
        "Tim",
        "Timmy",
        "Tobias",
        "Tom",
        "Tommy",
        "Tonny",
        "Torben",
        "Troels",
        "Uffe",
        "Ulf",
        "Ulrik",
        "Vagn",
        "Valdemar",
        "Verner",
        "Victor",
        "Villads",
        "Werner",
        "William",
        "Yan",
        "Yannick",
        "Yngve",
        "Zacharias",
        "Ziggy",
        "Øivind",
        "Øjvind",
        "Ørni",
        "Øvli",
        "Øystein",
        "Øyvind",
        "Åbjørn",
        "Aage",
        "Åge",
    )

    first_names_female = (
        "Abelone",
        "Agnes",
        "Agnete",
        "Alberte",
        "Alma",
        "Amalie",
        "Amanda",
        "Andrea",
        "Ane",
        "Anette",
        "Anna",
        "Anne",
        "Annemette",
        "Annette",
        "Asta",
        "Astrid",
        "Benedicte",
        "Benedikte",
        "Bente",
        "Benthe",
        "Berit",
        "Berta",
        "Beth",
        "Bettina",
        "Birgit",
        "Birgitte",
        "Birte",
        "Birthe",
        "Bitten",
        "Bodil",
        "Britt",
        "Britta",
        "Camilla",
        "Carina",
        "Carla",
        "Caroline",
        "Cathrine",
        "Catrine",
        "Cecilie",
        "Charlotte",
        "Christina",
        "Christine",
        "Cirkeline",
        "Clara",
        "Connie",
        "Conny",
        "Dagmar",
        "Dagny",
        "Daniella",
        "Dina",
        "Ditte",
        "Doris",
        "Dorte",
        "Dorthe",
        "Edith",
        "Elin",
        "Elisabeth",
        "Ella",
        "Ellen",
        "Elna",
        "Else",
        "Elsebeth",
        "Emilie",
        "Emily",
        "Emma",
        "Erna",
        "Esmarelda",
        "Ester",
        "Filippa",
        "Frederikke",
        "Freja",
        "Frida",
        "Gerda",
        "Gertrud",
        "Gitte",
        "Grete",
        "Grethe",
        "Gundhild",
        "Gunhild",
        "Gurli",
        "Gyda",
        "Hannah",
        "Hanne",
        "Heidi",
        "Helen",
        "Helle",
        "Henriette",
        "Herdis",
        "Iben",
        "Ida",
        "Inga",
        "Inge",
        "Ingelise",
        "Inger",
        "Ingrid",
        "Irma",
        "Isabella",
        "Jacobine",
        "Jacqueline",
        "Janne",
        "Janni",
        "Jannie",
        "Jasmin",
        "Jean",
        "Jenny",
        "Joan",
        "Johanne",
        "Jonna",
        "Josefine",
        "Josephine",
        "Julie",
        "Justina",
        "Jytte",
        "Karen",
        "Karin",
        "Karina",
        "Karla",
        "Karoline",
        "Katcha",
        "Katja",
        "Katrine",
        "Kirsten",
        "Kirstin",
        "Kirstine",
        "Klara",
        "Kristina",
        "Kristine",
        "Laura",
        "Lea",
        "Lena",
        "Lene",
        "Leonora",
        "Line",
        "Liva",
        "Lona",
        "Lone",
        "Lotte",
        "Louise",
        "Lærke",
        "Maiken",
        "Maja",
        "Majken",
        "Malene",
        "Malou",
        "Maren",
        "Margit",
        "Margrethe",
        "Maria",
        "Marianne",
        "Marie",
        "Marlene",
        "Mathilde",
        "Maya",
        "Merete",
        "Merethe",
        "Mette",
        "Mia",
        "Michala",
        "Michelle",
        "Mie",
        "Mille",
        "Mimi",
        "Minna",
        "Nadia",
        "Naja",
        "Nana",
        "Nanna",
        "Nanni",
        "Natasha",
        "Natasja",
        "Nete",
        "Nicoline",
        "Nina",
        "Nora",
        "Oda",
        "Odeline",
        "Odette",
        "Ofelia",
        "Olga",
        "Olivia",
        "Patricia",
        "Paula",
        "Paulina",
        "Pernille",
        "Pia",
        "Ragna",
        "Ragnhild",
        "Randi",
        "Rebecca",
        "Regitse",
        "Regitze",
        "Rikke",
        "Rita",
        "Ritt",
        "Ronja",
        "Rosa",
        "Ruth",
        "Sabine",
        "Sandra",
        "Sanne",
        "Sara",
        "Sarah",
        "Selma",
        "Signe",
        "Sigrid",
        "Silje",
        "Sille",
        "Simone",
        "Sine",
        "Sofia",
        "Sofie",
        "Solveig",
        "Solvej",
        "Sonja",
        "Sophie",
        "Stina",
        "Stine",
        "Susanne",
        "Sussanne",
        "Sussie",
        "Sys",
        "Sørine",
        "Søs",
        "Tammy",
        "Tanja",
        "Thea",
        "Tilde",
        "Tina",
        "Tine",
        "Tove",
        "Trine",
        "Ulla",
        "Ulrike",
        "Ursula",
        "Vera",
        "Victoria",
        "Viola",
        "Vivian",
        "Weena",
        "Winni",
        "Winnie",
        "Xenia",
        "Yasmin",
        "Yda",
        "Yrsa",
        "Yvonne",
        "Zahra",
        "Zara",
        "Zehnia",
        "Zelma",
        "Zenia",
        "Åse",
    )

    first_names = first_names_male + first_names_female

    last_names = (
        "Jensen",
        "Nielsen",
        "Hansen",
        "Pedersen",
        "Andersen",
        "Christensen",
        "Larsen",
        "Sørensen",
        "Rasmussen",
        "Petersen",
        "Jørgensen",
        "Madsen",
        "Kristensen",
        "Olsen",
        "Christiansen",
        "Thomsen",
        "Poulsen",
        "Johansen",
        "Knudsen",
        "Mortensen",
        "Møller",
        "Jacobsen",
        "Jakobsen",
        "Olesen",
        "Frederiksen",
        "Mikkelsen",
        "Henriksen",
        "Laursen",
        "Lund",
        "Schmidt",
        "Eriksen",
        "Holm",
        "Kristiansen",
        "Clausen",
        "Simonsen",
        "Svendsen",
        "Andreasen",
        "Iversen",
        "Jeppesen",
        "Mogensen",
        "Jespersen",
        "Nissen",
        "Lauridsen",
        "Frandsen",
        "Østergaard",
        "Jepsen",
        "Kjær",
        "Carlsen",
        "Vestergaard",
        "Jessen",
        "Nørgaard",
        "Dahl",
        "Christoffersen",
        "Skov",
        "Søndergaard",
        "Bertelsen",
        "Bruun",
        "Lassen",
        "Bach",
        "Gregersen",
        "Friis",
        "Johnsen",
        "Steffensen",
        "Kjeldsen",
        "Bech",
        "Krogh",
        "Lauritsen",
        "Danielsen",
        "Mathiesen",
        "Andresen",
        "Brandt",
        "Winther",
        "Toft",
        "Ravn",
        "Mathiasen",
        "Dam",
        "Holst",
        "Nilsson",
        "Lind",
        "Berg",
        "Schou",
        "Overgaard",
        "Kristoffersen",
        "Schultz",
        "Klausen",
        "Karlsen",
        "Paulsen",
        "Hermansen",
        "Thorsen",
        "Koch",
        "Thygesen",
    )

    prefixes_male = (
        "Hr",
        "Dr.",
        "Prof.",
        "Univ.Prof.",
    )

    prefixes_female = (
        "Fru",
        "Dr.",
        "Prof.",
        "Univ.Prof.",
    )



from .. import Provider as InternetProvider


class Provider(InternetProvider):

    free_email_domains = (
        "chello.at",
        "gmail.com",
        "gmx.at",
        "kabsi.at",
    )
    tlds = ("at", "co.at", "com", "net", "org")

    replacements = (
        ("ä", "ae"),
        ("Ä", "Ae"),
        ("ö", "oe"),
        ("Ö", "Oe"),
        ("ü", "ue"),
        ("Ü", "Ue"),
        ("ß", "ss"),
    )



from .. import Provider as LoremProvider


class Provider(LoremProvider):
    """Implement lorem provider for ``cs_CZ`` locale.

    Word list is drawn from the SYN2015.
    (representative corpus of contemporary written Czech published in December 2015)

    The word list is a list of the 2000 most common lemmas. Abbreviations and first names were removed.

    Sources:
    - https://wiki.korpus.cz/lib/exe/fetch.php/seznamy:syn2015_lemma_utf8.zip

    """

    word_list = (
        "a",
        "aby",
        "adresa",
        "Afrika",
        "agentura",
        "akce",
        "aktivita",
        "aktivní",
        "aktuální",
        "ale",
        "alespoň",
        "alkohol",
        "americký",
        "Amerika",
        "analýza",
        "anebo",
        "anglický",
        "ani",
        "aniž",
        "ano",
        "aplikace",
        "architekt",
        "areál",
        "armáda",
        "asi",
        "aspoň",
        "atmosféra",
        "auto",
        "autobus",
        "autor",
        "avšak",
        "ačkoli",
        "ať",
        "až",
        "babička",
        "banka",
        "barevný",
        "barva",
        "bavit",
        "bez",
        "bezpečnost",
        "bezpečnostní",
        "bezpečný",
        "blok",
        "blízko",
        "blízký",
        "blížit",
        "bod",
        "bohatý",
        "bohužel",
        "boj",
        "bojovat",
        "bok",
        "bolest",
        "bota",
        "boží",
        "branka",
        "bratr",
        "britský",
        "Brno",
        "brněnský",
        "brzy",
        "brána",
        "bránit",
        "brát",
        "budoucnost",
        "budoucí",
        "budova",
        "buď",
        "buňka",
        "bydlet",
        "byt",
        "byť",
        "bát",
        "bílý",
        "být",
        "bývalý",
        "bývat",
        "během",
        "běžet",
        "běžný",
        "břeh",
        "březen",
        "břicho",
        "bůh",
        "celek",
        "celkem",
        "celkový",
        "celý",
        "cena",
        "centrum",
        "cesta",
        "charakter",
        "chladný",
        "chlap",
        "chlapec",
        "chodba",
        "chodit",
        "chovat",
        "chování",
        "chránit",
        "chtít",
        "chuť",
        "chvilka",
        "chvíle",
        "chyba",
        "chybět",
        "chystat",
        "chytit",
        "chápat",
        "cigareta",
        "cizí",
        "co",
        "cokoli",
        "cosi",
        "což",
        "cukr",
        "cíl",
        "církev",
        "cítit",
        "daleko",
        "další",
        "daný",
        "datum",
        "daň",
        "dařit",
        "dcera",
        "dech",
        "den",
        "denně",
        "deník",
        "deset",
        "design",
        "deska",
        "desítka",
        "detail",
        "devět",
        "diskuse",
        "displej",
        "dispozice",
        "divadlo",
        "divoký",
        "divák",
        "dlaň",
        "dle",
        "dlouho",
        "dlouhodobý",
        "dlouhý",
        "dnes",
        "dneska",
        "dnešní",
        "dno",
        "do",
        "doba",
        "dobrý",
        "dobře",
        "docela",
        "docházet",
        "dodat",
        "dodnes",
        "dodávat",
        "dohoda",
        "dohromady",
        "dojem",
        "dojít",
        "dokonalý",
        "dokonce",
        "dokončit",
        "doktor",
        "dokud",
        "dokument",
        "dokázat",
        "dolar",
        "dolů",
        "doma",
        "domnívat",
        "domov",
        "domácnost",
        "domácí",
        "domů",
        "dopadnout",
        "dopis",
        "doplnit",
        "doporučovat",
        "doprava",
        "dopravní",
        "dorazit",
        "dosahovat",
        "doslova",
        "dospělý",
        "dost",
        "dostat",
        "dostatečný",
        "dostatečně",
        "dostupný",
        "dostávat",
        "dosud",
        "dosáhnout",
        "dotace",
        "dotknout",
        "doufat",
        "dovnitř",
        "dovolená",
        "dovolit",
        "dovést",
        "dozvědět",
        "dočkat",
        "drahý",
        "drobný",
        "druh",
        "druhý",
        "dráha",
        "držet",
        "duben",
        "duch",
        "duše",
        "dva",
        "dvacet",
        "dvakrát",
        "dvanáct",
        "dveře",
        "dvůr",
        "dále",
        "dáma",
        "dát",
        "dávat",
        "dávka",
        "dávno",
        "dávný",
        "délka",
        "déšť",
        "díky",
        "díl",
        "dílo",
        "díra",
        "dít",
        "dítě",
        "dívat",
        "dívka",
        "dějiny",
        "děkovat",
        "dělat",
        "dětský",
        "dětství",
        "dřevo",
        "dřevěný",
        "důkaz",
        "důležitý",
        "dům",
        "důsledek",
        "důvod",
        "ekonomický",
        "ekonomika",
        "elektrický",
        "energetický",
        "energie",
        "euro",
        "Evropa",
        "evropský",
        "existence",
        "existovat",
        "fakt",
        "faktor",
        "fakulta",
        "fanoušek",
        "festival",
        "film",
        "filmový",
        "finance",
        "finanční",
        "firma",
        "fond",
        "forma",
        "fotbal",
        "fotbalový",
        "fotka",
        "fotografie",
        "Francie",
        "francouzský",
        "fungovat",
        "funkce",
        "fyzický",
        "fáze",
        "generace",
        "gól",
        "hala",
        "herec",
        "hezký",
        "historický",
        "historie",
        "hladina",
        "hlas",
        "hlava",
        "hlavní",
        "hlavně",
        "hledat",
        "hledisko",
        "hledět",
        "hluboký",
        "hmota",
        "hmotnost",
        "hned",
        "hnutí",
        "hnědý",
        "hodina",
        "hodit",
        "hodlat",
        "hodnocení",
        "hodnota",
        "hodně",
        "holka",
        "hora",
        "horký",
        "horní",
        "hospodářský",
        "host",
        "hotel",
        "hotový",
        "hovořit",
        "hra",
        "hrad",
        "hranice",
        "hrdina",
        "hrozit",
        "hrozně",
        "hrát",
        "hráč",
        "hudba",
        "hudební",
        "hvězda",
        "hřiště",
        "i",
        "ideální",
        "informace",
        "informační",
        "informovat",
        "instituce",
        "internet",
        "internetový",
        "investice",
        "italský",
        "jak",
        "jakmile",
        "jako",
        "jaký",
        "jakýkoli",
        "jakýsi",
        "jaro",
        "jasný",
        "jasně",
        "jazyk",
        "jeden",
        "jedinec",
        "jediný",
        "jednak",
        "jednat",
        "jednoduchý",
        "jednoduše",
        "jednotka",
        "jednotlivý",
        "jednou",
        "jednání",
        "jeho",
        "jejich",
        "její",
        "jelikož",
        "jemný",
        "jen",
        "jenom",
        "jenž",
        "jenže",
        "jestli",
        "jestliže",
        "jet",
        "jev",
        "jezdit",
        "ještě",
        "jinak",
        "jinde",
        "jiný",
        "jistota",
        "jistý",
        "jistě",
        "již",
        "jižní",
        "jmenovat",
        "jméno",
        "jo",
        "já",
        "jádro",
        "jídlo",
        "jíst",
        "jít",
        "jízda",
        "k",
        "kam",
        "kamarád",
        "kamenný",
        "kamera",
        "kancelář",
        "kapacita",
        "kapela",
        "kapitola",
        "kapitán",
        "kapsa",
        "kariéra",
        "karta",
        "kategorie",
        "každý",
        "kde",
        "kdo",
        "kdy",
        "kdyby",
        "kdykoli",
        "kdysi",
        "když",
        "kilometr",
        "klasický",
        "klid",
        "klidný",
        "klidně",
        "klient",
        "klub",
        "kluk",
        "klást",
        "klíč",
        "klíčový",
        "kniha",
        "knihovna",
        "knížka",
        "kolega",
        "kolem",
        "koleno",
        "kolik",
        "kolo",
        "kombinace",
        "komise",
        "komora",
        "komunikace",
        "konat",
        "koncert",
        "konec",
        "konečný",
        "konečně",
        "konkrétní",
        "konstrukce",
        "kontakt",
        "kontrola",
        "končit",
        "kopec",
        "koruna",
        "kost",
        "kostel",
        "koupit",
        "kousek",
        "kočka",
        "košile",
        "kraj",
        "krajina",
        "krajský",
        "krev",
        "krize",
        "krk",
        "krok",
        "kromě",
        "kruh",
        "král",
        "krása",
        "krásný",
        "krátce",
        "krátký",
        "který",
        "kuchyně",
        "kultura",
        "kulturní",
        "kurs",
        "kus",
        "kvalita",
        "kvalitní",
        "květ",
        "květen",
        "kvůli",
        "kámen",
        "káva",
        "křeslo",
        "křičet",
        "křídlo",
        "kůň",
        "kůže",
        "led",
        "leden",
        "lehce",
        "lehký",
        "les",
        "letadlo",
        "letní",
        "letos",
        "letošní",
        "levný",
        "levý",
        "ležet",
        "lidový",
        "lidský",
        "liga",
        "linka",
        "list",
        "listopad",
        "literatura",
        "lišit",
        "lokalita",
        "Londýn",
        "loď",
        "loňský",
        "lze",
        "láska",
        "látka",
        "lék",
        "lékař",
        "léto",
        "léčba",
        "líbit",
        "majetek",
        "majitel",
        "malý",
        "maminka",
        "manažer",
        "manžel",
        "manželka",
        "mapa",
        "maso",
        "materiál",
        "matka",
        "metoda",
        "metr",
        "mezi",
        "mezinárodní",
        "miliarda",
        "milimetr",
        "milión",
        "milovat",
        "milý",
        "mimo",
        "ministerstvo",
        "ministr",
        "minulost",
        "minulý",
        "minuta",
        "mistr",
        "mladík",
        "mladý",
        "mluvit",
        "mluvčí",
        "mléko",
        "mnohem",
        "mnoho",
        "mnohý",
        "množství",
        "mobil",
        "mobilní",
        "moc",
        "moci",
        "model",
        "moderní",
        "modrý",
        "moment",
        "Morava",
        "most",
        "motor",
        "mozek",
        "moře",
        "možnost",
        "možná",
        "možný",
        "mrtvý",
        "muset",
        "muzeum",
        "muž",
        "my",
        "mysl",
        "myslet",
        "myšlenka",
        "málo",
        "máma",
        "médium",
        "míra",
        "mírně",
        "místnost",
        "místní",
        "místo",
        "mít",
        "měnit",
        "město",
        "městský",
        "měsíc",
        "můj",
        "na",
        "nabídka",
        "nabídnout",
        "nabízet",
        "nacházet",
        "nad",
        "nadále",
        "naděje",
        "nahoru",
        "nahradit",
        "najednou",
        "najít",
        "nakonec",
        "nalézt",
        "naopak",
        "napadnout",
        "naposledy",
        "naprosto",
        "napsat",
        "napětí",
        "například",
        "narazit",
        "narodit",
        "nastat",
        "nastoupit",
        "natolik",
        "naučit",
        "navrhnout",
        "navzdory",
        "navíc",
        "navštívit",
        "nazývat",
        "naštěstí",
        "ne",
        "nebe",
        "nebezpečí",
        "nebo",
        "neboť",
        "nechat",
        "nechávat",
        "nedostatek",
        "nedávno",
        "neděle",
        "nehoda",
        "nejen",
        "nejprve",
        "nemoc",
        "nemocnice",
        "nemocný",
        "nepřítel",
        "neustále",
        "nezbytný",
        "než",
        "nic",
        "nicméně",
        "nijak",
        "nikdo",
        "nikdy",
        "nikoli",
        "no",
        "noc",
        "noha",
        "norma",
        "normální",
        "nos",
        "nosit",
        "novinka",
        "noviny",
        "novinář",
        "nový",
        "nově",
        "noční",
        "nutit",
        "nutný",
        "nyní",
        "nábytek",
        "nádherný",
        "náhle",
        "náhodou",
        "náklad",
        "nákup",
        "nálada",
        "náměstí",
        "nápad",
        "národ",
        "národní",
        "nárok",
        "náročný",
        "následek",
        "následně",
        "následovat",
        "následující",
        "nástroj",
        "návrat",
        "návrh",
        "návštěva",
        "návštěvník",
        "název",
        "názor",
        "náš",
        "nést",
        "nízký",
        "nýbrž",
        "něco",
        "nějak",
        "nějaký",
        "někde",
        "někdo",
        "někdy",
        "několik",
        "několikrát",
        "některý",
        "Němec",
        "Německo",
        "německý",
        "o",
        "oba",
        "obava",
        "obchod",
        "obchodní",
        "období",
        "obec",
        "obecný",
        "obecně",
        "objekt",
        "objem",
        "objevit",
        "objevovat",
        "oblast",
        "oblečení",
        "obličej",
        "oblíbený",
        "obor",
        "obr",
        "obrana",
        "obraz",
        "obrovský",
        "obrátit",
        "obrázek",
        "obsah",
        "obsahovat",
        "obvod",
        "obvykle",
        "obvyklý",
        "obyvatel",
        "obyčejný",
        "občan",
        "občanský",
        "občas",
        "oběť",
        "ochrana",
        "ocitnout",
        "od",
        "odborník",
        "odborný",
        "odchod",
        "odcházet",
        "oddělení",
        "odejít",
        "odhalit",
        "odjet",
        "odkud",
        "odlišný",
        "odmítat",
        "odmítnout",
        "odpoledne",
        "odpor",
        "odpovídat",
        "odpovědět",
        "odpověď",
        "oheň",
        "ohled",
        "okamžik",
        "okamžitě",
        "okno",
        "oko",
        "okolnost",
        "okolní",
        "okolo",
        "okolí",
        "okraj",
        "olej",
        "omezený",
        "on",
        "onemocnění",
        "onen",
        "oni",
        "opakovat",
        "opatření",
        "operace",
        "operační",
        "oprava",
        "opravdu",
        "oproti",
        "opustit",
        "opět",
        "organizace",
        "orgán",
        "osm",
        "osoba",
        "osobnost",
        "osobní",
        "osobně",
        "ostatní",
        "ostatně",
        "Ostrava",
        "ostrov",
        "ostrý",
        "osud",
        "otec",
        "otevřený",
        "otevřít",
        "otočit",
        "otázka",
        "ovlivnit",
        "ovšem",
        "označit",
        "označovat",
        "oznámit",
        "ozvat",
        "očekávat",
        "pacient",
        "padat",
        "padesát",
        "padnout",
        "pak",
        "pamatovat",
        "památka",
        "paměť",
        "pan",
        "paní",
        "papír",
        "parametr",
        "park",
        "partner",
        "patnáct",
        "patro",
        "patřit",
        "paže",
        "peníze",
        "pes",
        "pevný",
        "pevně",
        "pivo",
        "planeta",
        "platit",
        "plný",
        "plně",
        "plocha",
        "plyn",
        "Plzeň",
        "plán",
        "plánovat",
        "po",
        "pobyt",
        "pochopit",
        "pochopitelně",
        "pocházet",
        "pocit",
        "pod",
        "podat",
        "podařit",
        "podepsat",
        "podivný",
        "podlaha",
        "podle",
        "podmínka",
        "podnik",
        "podoba",
        "podobný",
        "podobně",
        "podpora",
        "podporovat",
        "podpořit",
        "podstata",
        "podstatný",
        "podzim",
        "podávat",
        "podíl",
        "podílet",
        "podívat",
        "pohled",
        "pohlédnout",
        "pohyb",
        "pohybovat",
        "pojem",
        "pokaždé",
        "pokoj",
        "pokoušet",
        "pokračovat",
        "pokud",
        "pokus",
        "pokusit",
        "pole",
        "policejní",
        "policie",
        "policista",
        "politický",
        "politik",
        "politika",
        "poloha",
        "polovina",
        "položit",
        "pomalu",
        "pomoc",
        "pomoci",
        "pomocí",
        "pomyslet",
        "pomáhat",
        "poměr",
        "poměrně",
        "poněkud",
        "popis",
        "popisovat",
        "poprvé",
        "popsat",
        "populace",
        "poradit",
        "posadit",
        "poskytnout",
        "poskytovat",
        "poslat",
        "poslední",
        "poslouchat",
        "postava",
        "postavení",
        "postavit",
        "postel",
        "postoj",
        "postup",
        "postupně",
        "potkat",
        "potom",
        "potravina",
        "potvrdit",
        "poté",
        "potíž",
        "potřeba",
        "potřebný",
        "potřebovat",
        "pouhý",
        "pouze",
        "použití",
        "použít",
        "používat",
        "povaha",
        "považovat",
        "povinnost",
        "povrch",
        "povést",
        "povídat",
        "povědět",
        "pozdní",
        "pozdě",
        "pozemek",
        "pozice",
        "pozitivní",
        "poznamenat",
        "poznat",
        "poznámka",
        "pozor",
        "pozornost",
        "pozorovat",
        "pozvat",
        "počasí",
        "počet",
        "počkat",
        "počátek",
        "počítat",
        "počítač",
        "pořád",
        "pořádek",
        "pořádně",
        "pořídit",
        "požadavek",
        "požádat",
        "prach",
        "pracovat",
        "pracovní",
        "pracovník",
        "Praha",
        "prakticky",
        "praktický",
        "pravda",
        "pravděpodobně",
        "pravidelný",
        "pravidelně",
        "pravidlo",
        "pravý",
        "praxe",
        "pražský",
        "premiér",
        "prezident",
        "princip",
        "pro",
        "problém",
        "probudit",
        "probíhat",
        "proběhnout",
        "procento",
        "proces",
        "procházet",
        "prodat",
        "prodej",
        "produkce",
        "produkt",
        "prodávat",
        "profesor",
        "program",
        "prohlásit",
        "projekt",
        "projev",
        "projevit",
        "projevovat",
        "projít",
        "promluvit",
        "proměnit",
        "prosinec",
        "prosit",
        "prostor",
        "prostě",
        "prostředek",
        "prostřednictvím",
        "prostředí",
        "proti",
        "proto",
        "protože",
        "proud",
        "provedení",
        "provoz",
        "provádět",
        "provést",
        "prozradit",
        "proč",
        "prst",
        "prvek",
        "první",
        "pryč",
        "práce",
        "právní",
        "právo",
        "právě",
        "prázdný",
        "prý",
        "průběh",
        "průmysl",
        "průměr",
        "průměrný",
        "psát",
        "pták",
        "ptát",
        "pustit",
        "pád",
        "pán",
        "pár",
        "pátek",
        "péče",
        "píseň",
        "pít",
        "pěkný",
        "pěkně",
        "pět",
        "přece",
        "před",
        "předchozí",
        "předem",
        "především",
        "předmět",
        "přednost",
        "přední",
        "předpoklad",
        "předpokládat",
        "předseda",
        "představa",
        "představení",
        "představit",
        "představovat",
        "předtím",
        "přejít",
        "překvapit",
        "přemýšlet",
        "přes",
        "přesný",
        "přesně",
        "přestat",
        "přesto",
        "přestože",
        "přesvědčit",
        "převzít",
        "přečíst",
        "přežít",
        "při",
        "přibližně",
        "přiblížit",
        "přicházet",
        "přidat",
        "přijet",
        "přijmout",
        "přijít",
        "přikývnout",
        "přinášet",
        "přinést",
        "připadat",
        "připojit",
        "připomenout",
        "připomínat",
        "připravený",
        "připravit",
        "připravovat",
        "přirozený",
        "přitom",
        "přivést",
        "přiznat",
        "přičemž",
        "přání",
        "přát",
        "příběh",
        "příjem",
        "příjemný",
        "příklad",
        "příležitost",
        "příliš",
        "přímo",
        "přímý",
        "případ",
        "případný",
        "případně",
        "příprava",
        "příroda",
        "přírodní",
        "příslušný",
        "příspěvek",
        "přístroj",
        "přístup",
        "přítel",
        "přítomnost",
        "přítomný",
        "příčina",
        "příští",
        "půda",
        "půl",
        "působení",
        "působit",
        "původ",
        "původní",
        "původně",
        "rada",
        "radnice",
        "radost",
        "rameno",
        "reagovat",
        "reakce",
        "realita",
        "realizace",
        "region",
        "regionální",
        "rekonstrukce",
        "republika",
        "restaurace",
        "ret",
        "reálný",
        "režim",
        "režisér",
        "riziko",
        "rodina",
        "rodinný",
        "rodič",
        "roh",
        "rok",
        "role",
        "román",
        "rostlina",
        "rovnice",
        "rovnou",
        "rovněž",
        "rozdíl",
        "rozdělit",
        "rozhodnout",
        "rozhodnutí",
        "rozhodně",
        "rozhodovat",
        "rozhovor",
        "rozměr",
        "rozpočet",
        "rozsah",
        "rozsáhlý",
        "rozumět",
        "rozvoj",
        "rozšířit",
        "ročník",
        "ruka",
        "Rusko",
        "ruský",
        "ryba",
        "rychle",
        "rychlost",
        "rychlý",
        "rád",
        "rámec",
        "rána",
        "ráno",
        "růst",
        "různý",
        "s",
        "samostatný",
        "samotný",
        "samozřejmě",
        "samý",
        "sbor",
        "sbírka",
        "schod",
        "schopnost",
        "schopný",
        "scéna",
        "sdružení",
        "sdělit",
        "se",
        "sedm",
        "sednout",
        "sedět",
        "sejít",
        "sem",
        "sen",
        "seriál",
        "sestra",
        "setkat",
        "setkání",
        "severní",
        "seznam",
        "seznámit",
        "sezona",
        "sice",
        "signál",
        "silnice",
        "silný",
        "silně",
        "situace",
        "skladba",
        "sklo",
        "skončit",
        "skoro",
        "skrývat",
        "skupina",
        "skutečnost",
        "skutečný",
        "skutečně",
        "skvělý",
        "skála",
        "slabý",
        "slavný",
        "sledovat",
        "slečna",
        "sloužit",
        "Slovensko",
        "slovenský",
        "slovo",
        "složitý",
        "složka",
        "slunce",
        "sluneční",
        "služba",
        "slyšet",
        "slza",
        "smlouva",
        "smrt",
        "smysl",
        "smát",
        "smích",
        "směr",
        "smět",
        "snad",
        "snadno",
        "snadný",
        "snaha",
        "snažit",
        "sníh",
        "snímek",
        "snížit",
        "sobota",
        "sociální",
        "sotva",
        "soubor",
        "soud",
        "souhlasit",
        "soukromý",
        "soupeř",
        "soused",
        "soustava",
        "soustředit",
        "soutěž",
        "souviset",
        "souvislost",
        "současnost",
        "současný",
        "současně",
        "součást",
        "spadnout",
        "spatřit",
        "specifický",
        "speciální",
        "spisovatel",
        "splnit",
        "spodní",
        "spojení",
        "spojený",
        "spojit",
        "spokojený",
        "společenský",
        "společnost",
        "společný",
        "společně",
        "spolu",
        "spolupráce",
        "spor",
        "sport",
        "sportovní",
        "spotřeba",
        "spousta",
        "spočívat",
        "správa",
        "správný",
        "správně",
        "spustit",
        "spánek",
        "spát",
        "spíš",
        "srdce",
        "srovnání",
        "srpen",
        "stanice",
        "stanovit",
        "starat",
        "starost",
        "starosta",
        "starý",
        "stav",
        "stavba",
        "stavební",
        "stavět",
        "stačit",
        "stejný",
        "stejně",
        "stihnout",
        "sto",
        "století",
        "stopa",
        "stovka",
        "strach",
        "strana",
        "strategie",
        "strašně",
        "stroj",
        "strom",
        "struktura",
        "stránka",
        "strávit",
        "student",
        "studený",
        "studie",
        "studium",
        "studovat",
        "stupeň",
        "styl",
        "stáhnout",
        "stále",
        "stát",
        "státní",
        "stávat",
        "stín",
        "stěna",
        "střecha",
        "střední",
        "stůl",
        "suchý",
        "svatý",
        "svaz",
        "svoboda",
        "svobodný",
        "svět",
        "světlo",
        "světový",
        "svůj",
        "symbol",
        "syn",
        "systém",
        "sál",
        "sám",
        "série",
        "síla",
        "síť",
        "sůl",
        "tabulka",
        "tady",
        "tajemství",
        "tajný",
        "tak",
        "takhle",
        "takový",
        "takto",
        "taky",
        "takzvaný",
        "také",
        "takže",
        "tam",
        "technický",
        "technika",
        "technologie",
        "teda",
        "tedy",
        "tehdejší",
        "tehdy",
        "telefon",
        "televize",
        "televizní",
        "temný",
        "ten",
        "tenhle",
        "tenkrát",
        "tento",
        "tentokrát",
        "tentýž",
        "teorie",
        "teplo",
        "teplota",
        "teplý",
        "teprve",
        "termín",
        "test",
        "text",
        "teď",
        "ticho",
        "tichý",
        "tisíc",
        "titul",
        "tiše",
        "tlak",
        "tlačítko",
        "tma",
        "tmavý",
        "to",
        "tolik",
        "totiž",
        "touha",
        "toužit",
        "tradice",
        "tradiční",
        "trasa",
        "trať",
        "trend",
        "trenér",
        "trest",
        "trh",
        "trochu",
        "trpět",
        "trvat",
        "tráva",
        "tu",
        "turnaj",
        "tušit",
        "tvar",
        "tvorba",
        "tvořit",
        "tvrdit",
        "tvrdý",
        "tvář",
        "tvůj",
        "ty",
        "typ",
        "typický",
        "tábor",
        "táhnout",
        "táta",
        "téma",
        "téměř",
        "též",
        "tón",
        "týden",
        "týkat",
        "tým",
        "týž",
        "tělo",
        "těsně",
        "těšit",
        "těžko",
        "těžký",
        "třeba",
        "třetina",
        "třetí",
        "tři",
        "třicet",
        "třída",
        "u",
        "ucho",
        "udržet",
        "udržovat",
        "událost",
        "udělat",
        "ukazovat",
        "ukázat",
        "ulice",
        "uložit",
        "umožnit",
        "umožňovat",
        "umístit",
        "umělec",
        "umělecký",
        "umělý",
        "umění",
        "umět",
        "unie",
        "univerzita",
        "upozornit",
        "uprostřed",
        "určený",
        "určit",
        "určitý",
        "určitě",
        "uskutečnit",
        "usmát",
        "usmívat",
        "utkání",
        "utéci",
        "uvažovat",
        "uvedený",
        "uvidět",
        "uvnitř",
        "uvádět",
        "uvést",
        "uvědomit",
        "uvědomovat",
        "uzavřít",
        "učinit",
        "učit",
        "učitel",
        "už",
        "uživatel",
        "užívat",
        "v",
        "vadit",
        "varianta",
        "vazba",
        "vedení",
        "vedle",
        "vedoucí",
        "vejít",
        "velice",
        "velikost",
        "veliký",
        "velký",
        "velmi",
        "ven",
        "venku",
        "verze",
        "vesmír",
        "vesnice",
        "večer",
        "večeře",
        "veřejnost",
        "veřejný",
        "veškerý",
        "vhodný",
        "viditelný",
        "vidět",
        "vina",
        "viset",
        "viz",
        "vlak",
        "vlas",
        "vlastnost",
        "vlastní",
        "vlastně",
        "vliv",
        "vlna",
        "vloni",
        "vláda",
        "vnitřní",
        "vnímat",
        "vnější",
        "voda",
        "vodní",
        "vojenský",
        "voják",
        "volat",
        "volba",
        "volit",
        "volný",
        "vozidlo",
        "vracet",
        "vrchol",
        "vrstva",
        "vrátit",
        "vstoupit",
        "vstup",
        "vstát",
        "vteřina",
        "vy",
        "vybavit",
        "vybraný",
        "vybrat",
        "vybírat",
        "vycházet",
        "vydat",
        "vydržet",
        "vydání",
        "vydávat",
        "vyhnout",
        "vyhrát",
        "vyjádřit",
        "vyjít",
        "vypadat",
        "vyprávět",
        "vyrazit",
        "vyrábět",
        "vyskytovat",
        "vysoko",
        "vysoký",
        "vystoupit",
        "vystupovat",
        "vysvětlit",
        "vysvětlovat",
        "vytvořit",
        "vytvářet",
        "vytáhnout",
        "využití",
        "využít",
        "využívat",
        "vyvolat",
        "vyzkoušet",
        "vyřešit",
        "vyžadovat",
        "vzduch",
        "vzdálenost",
        "vzdálený",
        "vzdát",
        "vzdělání",
        "vzdělávání",
        "vzhledem",
        "vznik",
        "vznikat",
        "vzniknout",
        "vzor",
        "vzpomenout",
        "vzpomínat",
        "vzpomínka",
        "vztah",
        "vzájemný",
        "vzít",
        "váha",
        "válka",
        "Vánoce",
        "vánoční",
        "váš",
        "vážný",
        "vážně",
        "vést",
        "víc",
        "více",
        "víkend",
        "víno",
        "víra",
        "vítr",
        "vítěz",
        "vítězství",
        "výbor",
        "výběr",
        "východ",
        "východní",
        "výchova",
        "výhoda",
        "výjimka",
        "výkon",
        "výměna",
        "výraz",
        "výrazný",
        "výrazně",
        "výroba",
        "výrobce",
        "výrobek",
        "výsledek",
        "výstava",
        "výstavba",
        "vývoj",
        "výzkum",
        "význam",
        "významný",
        "výzva",
        "výše",
        "výška",
        "včera",
        "včetně",
        "věc",
        "věda",
        "vědec",
        "vědecký",
        "vědomí",
        "vědět",
        "věk",
        "věnovat",
        "věta",
        "větev",
        "většina",
        "většinou",
        "vězení",
        "věřit",
        "věž",
        "však",
        "všechen",
        "všimnout",
        "všude",
        "vůbec",
        "vůle",
        "vůně",
        "vůz",
        "vůči",
        "vždy",
        "vždycky",
        "vždyť",
        "z",
        "za",
        "zabránit",
        "zabít",
        "zabývat",
        "zachovat",
        "zachránit",
        "zadní",
        "zahrada",
        "zahraniční",
        "zahraničí",
        "zahájit",
        "zajistit",
        "zajímat",
        "zajímavý",
        "zajít",
        "zakázka",
        "založit",
        "zamířit",
        "zaměstnanec",
        "zaměřit",
        "zaplatit",
        "zapomenout",
        "zas",
        "zase",
        "zasmát",
        "zastavit",
        "zasáhnout",
        "zatím",
        "zatímco",
        "zaujmout",
        "zavolat",
        "zavést",
        "zavřít",
        "zaznamenat",
        "začátek",
        "začínat",
        "začít",
        "zařízení",
        "zažít",
        "zbavit",
        "zboží",
        "zbraň",
        "zbytek",
        "zbýt",
        "zbývat",
        "zcela",
        "zda",
        "zde",
        "zdravotní",
        "zdraví",
        "zdravý",
        "zdroj",
        "zdát",
        "zejména",
        "zelený",
        "země",
        "zemřít",
        "zeptat",
        "zeď",
        "zhruba",
        "zima",
        "zimní",
        "zisk",
        "zjistit",
        "zkouška",
        "zkrátka",
        "zkusit",
        "zkušenost",
        "zlato",
        "zlatý",
        "zlý",
        "zmizet",
        "zmínit",
        "zmíněný",
        "změna",
        "změnit",
        "znak",
        "znalost",
        "znamenat",
        "značka",
        "značný",
        "znovu",
        "známý",
        "znát",
        "znít",
        "zpravidla",
        "zpráva",
        "zpátky",
        "zpívat",
        "zpět",
        "způsob",
        "způsobit",
        "zrovna",
        "ztratit",
        "ztrácet",
        "ztráta",
        "zub",
        "zvednout",
        "zvládnout",
        "zvláštní",
        "zvláště",
        "zvlášť",
        "zvolit",
        "zvuk",
        "zvyšovat",
        "zvíře",
        "zvýšení",
        "zvýšit",
        "záda",
        "zájem",
        "zákazník",
        "základ",
        "základní",
        "zákon",
        "záležet",
        "záležitost",
        "zámek",
        "západ",
        "západní",
        "zápas",
        "zároveň",
        "zásada",
        "zásadní",
        "zásah",
        "zástupce",
        "závislost",
        "závislý",
        "závod",
        "závěr",
        "záznam",
        "září",
        "zážitek",
        "získat",
        "zítra",
        "zřejmě",
        "zůstat",
        "zůstávat",
        "údaj",
        "úkol",
        "únor",
        "úplný",
        "úplně",
        "úprava",
        "úroveň",
        "úsek",
        "úsměv",
        "úspěch",
        "úspěšný",
        "ústa",
        "ústav",
        "útok",
        "útočník",
        "úvaha",
        "území",
        "úzký",
        "účast",
        "účastník",
        "účel",
        "účet",
        "účinek",
        "úřad",
        "úžasný",
        "čaj",
        "čas",
        "časopis",
        "časový",
        "často",
        "častý",
        "Čech",
        "Čechy",
        "čekat",
        "čelo",
        "černý",
        "čerstvý",
        "červen",
        "červenec",
        "červený",
        "Česko",
        "český",
        "či",
        "čin",
        "činit",
        "činnost",
        "čistý",
        "člen",
        "člověk",
        "článek",
        "čtenář",
        "čtvrtý",
        "čtyři",
        "část",
        "částice",
        "částka",
        "Čína",
        "čínský",
        "číslo",
        "číst",
        "řada",
        "ředitel",
        "řeka",
        "řeč",
        "řešení",
        "řešit",
        "řidič",
        "řád",
        "říci",
        "řídit",
        "říjen",
        "říkat",
        "řízení",
        "šance",
        "šaty",
        "šedý",
        "šest",
        "široký",
        "škoda",
        "škola",
        "školní",
        "špatný",
        "špatně",
        "štěstí",
        "šéf",
        "šťastný",
        "že",
        "žena",
        "ženský",
        "židle",
        "život",
        "životní",
        "živý",
        "žlutý",
        "žádat",
        "žádný",
        "žádost",
        "žák",
        "žít",
    )



"""it_IT ssn provider (yields italian fiscal codes)"""

from string import ascii_uppercase, digits

from .. import Provider as SsnProvider

ALPHANUMERICS = sorted(digits + ascii_uppercase)
ALPHANUMERICS_DICT = {char: index for index, char in enumerate(ALPHANUMERICS)}
CHECKSUM_TABLE = (
    (
        1,
        0,
        5,
        7,
        9,
        13,
        15,
        17,
        19,
        21,
        1,
        0,
        5,
        7,
        9,
        13,
        15,
        17,
        19,
        21,
        2,
        4,
        18,
        20,
        11,
        3,
        6,
        8,
        12,
        14,
        16,
        10,
        22,
        25,
        24,
        23,
    ),
    (
        0,
        1,
        2,
        3,
        4,
        5,
        6,
        7,
        8,
        9,
        0,
        1,
        2,
        3,
        4,
        5,
        6,
        7,
        8,
        9,
        10,
        11,
        12,
        13,
        14,
        15,
        16,
        17,
        18,
        19,
        20,
        21,
        22,
        23,
        24,
        25,
    ),
)


def checksum(value: str) -> str:
    """
    Calculates the checksum char used for the 16th char.
    Author: Vincenzo Palazzo
    """
    return chr(65 + sum(CHECKSUM_TABLE[index % 2][ALPHANUMERICS_DICT[char]] for index, char in enumerate(value)) % 26)


class Provider(SsnProvider):
    """
    Generates italian fiscal codes.
    """

    fiscal_code_format = "??????##?##?###"

    def ssn(self) -> str:
        code = self.bothify(self.fiscal_code_format).upper()
        return code + checksum(code)

    vat_id_formats = ("IT###########",)

    def vat_id(self) -> str:
        """
        http://ec.europa.eu/taxation_customs/vies/faq.html#item_11
        :return: A random Italian VAT ID
        """
        return self.bothify(self.random_element(self.vat_id_formats))



from .. import Provider as InternetProvider


class Provider(InternetProvider):

    tlds = ("com", "com", "com", "net", "org", "no", "no", "no", "no", "no")

    replacements = (
        ("æ", "ae"),
        ("Æ", "Ae"),
        ("ø", "oe"),
        ("Ø", "Oe"),
        ("å", "aa"),
        ("Å", "Aa"),
        ("ä", "ae"),
        ("Ä", "Ae"),
        ("ö", "oe"),
        ("Ö", "Oe"),
        ("ü", "ue"),
        ("Ü", "Ue"),
    )



from ..es_ES import Provider as PersonProvider


class Provider(PersonProvider):
    """
    Adds popular Catalan names.
    https://www.idescat.cat/pub/?id=aec&n=946&lang=es&t=2018
    https://www.idescat.cat/pub/?id=aec&n=947&lang=es&t=2018
    """

    first_names_male = (
        "Adam",
        "Albert",
        "Aleix",
        "Álex",
        "Antonio",
        "Arnau",
        "Biel",
        "Bruno",
        "Carlos",
        "Daniel",
        "David",
        "Enzo",
        "Èric",
        "Francisco",
        "Hugo",
        "Jan",
        "Javier",
        "Joan",
        "Jordi",
        "Jorge",
        "Josep",
        "José",
        "José María",
        "Juan",
        "Leo",
        "Lucas",
        "Manuel",
        "Marc",
        "Martí",
        "Max",
        "Miguel",
        "Nil",
        "Pau",
        "Pedro",
        "Pol",
        "Ramón",
        "Xavier",
    )

    first_names_female = (
        "Abril",
        "Aina",
        "Ana",
        "Anna",
        "Antonia",
        "Antònia",
        "Arlet",
        "Carla",
        "Carmen",
        "Chlóe",
        "Clàudia",
        "Cristina",
        "Dolores",
        "Emma",
        "Francisca",
        "Isabel",
        "Jana",
        "Josefa",
        "Júlia",
        "Laia",
        "Laura",
        "Lucia",
        "Marta",
        "Martina",
        "María",
        "María Del Carmen",
        "María Dolores",
        "María Teresa",
        "Mia",
        "Montserrat",
        "Noa",
        "Núria",
        "Ona",
        "Paula",
        "Rosa",
        "Sara",
        "Sofía",
        "Sílvia",
        "Valèria",
    )

    first_names = first_names_male + first_names_female



from .. import Provider as InternetProvider


class Provider(InternetProvider):
    # Data taken from
    # https://github.com/fzaninotto/Faker/blob/master/src/Faker/Provider/en_GB/Internet.php

    free_email_domains = (
        "gmail.com",
        "yahoo.com",
        "hotmail.com",
        "yahoo.co.uk",
        "hotmail.co.uk",
        "outlook.com",
    )

    tlds = (
        "com",
        "com",
        "com",
        "com",
        "com",
        "com",
        "biz",
        "info",
        "net",
        "org",
        "co.uk",
    )



from .. import Provider as LoremProvider


class Provider(LoremProvider):
    """Implement lorem provider for ``th_TH`` locale.

    Word list is randomly drawn from the Thailand's Ministry of Education,
    removing compound words and long words, adding common words (like
    prepositions) and few of regional words.

    Sources:

    - http://www.arts.chula.ac.th/~ling/TTC/id-4.html
    - https://www.sanook.com/campus/1390689/
    - https://www.sanook.com/campus/1397677/
    - https://www.sanook.com/campus/1392241/
    """

    word_connector = ""  # Thai writing has no word divider
    sentence_punctuation = " "  # single space
    word_list = (
        "กตัญญู",
        "กบ",
        "กรดไหลย้อน",
        "กรรมการ",
        "กระจาย",
        "กระถาง",
        "กล",
        "กล่อง",
        "กล้า",
        "กลาง",
        "กลางคืน",
        "กล่าว",
        "กว้าง",
        "กะเพรา",
        "กะละมัง",
        "กับ",
        "ก้าง",
        "กาม",
        "การ",
        "กำ",
        "กำไร",
        "กิ่งไม้",
        "กิจกรรม",
        "กิน",
        "กิโลเมตร",
        "กีฬา",
        "กู",
        "กูเกิล",
        "เกม",
        "เกาหลี",
        "แก้ว",
        "แกะ",
        "แก",
        "แก่",
        "แก้",
        "โก๋แก่",
        "โกง",
        "ขนม",
        "ขนมชั้น",
        "ของหวาน",
        "ขัด",
        "ขันน้ำ",
        "ข้าง",
        "ขาดเคิ่ง",
        "ข้าว",
        "ข้าวเจ้า",
        "ข้าวหมูแดง",
        "ขี่",
        "ขี้ไคล",
        "ขี้ดิน",
        "ขุด",
        "เขยิบ",
        "เขยื้อน",
        "เข้ารหัส",
        "แข่งขัน",
        "แข็ง",
        "แข้ง",
        "ไข่",
        "คนไข้",
        "คนตาย",
        "คบ",
        "คมนาคม",
        "ครอง",
        "ครู",
        "คลาน",
        "ควร",
        "ความ",
        "คอก",
        "คอมมิวนิสต์",
        "ค่อย",
        "คะแนน",
        "คั่ว",
        "คาว",
        "คำถาม",
        "คำสั่ง",
        "คู่",
        "เคย",
        "เครื่องบิน",
        "เคเอฟซี",
        "เคารพ",
        "แคะ",
        "โควิด",
        "ไค้หัน",
        "งม",
        "ง่วง",
        "เงา",
        "โง่",
        "จะไปพั่ง",
        "จัด",
        "จาก",
        "จ๋า",
        "เจ็บไข้",
        "แจ่มใส",
        "ใจ",
        "ฉีด",
        "เฉย",
        "ชนิด",
        "ชะนี",
        "ช้า",
        "ชาว",
        "ชาวนา",
        "ชิง",
        "ชุดนอน",
        "ชุมนุม",
        "ชู",
        "เช้า",
        "เชื่อม",
        "เชื้อโรค",
        "เชื่อ",
        "ไชโย",
        "ซ่อน",
        "ซ่อมเบิ่ง",
        "ซอย",
        "ซี่",
        "แซง",
        "ด้วย",
        "ดอกไม้",
        "ดอง",
        "ดังนี้",
        "ด้าย",
        "ดาวเทียม",
        "ดำ",
        "ดี",
        "ดึก",
        "ดู",
        "เดี่ยว",
        "โดย",
        "ได้แก่",
        "ตกลง",
        "ต้น",
        "ตรวจ",
        "ตลอด",
        "ตอก",
        "ตอใด",
        "ต่อ",
        "ตะแกรง",
        "ตะปู",
        "ตั้งแต่",
        "ตับ",
        "ตัวเมีย",
        "ตัวอย่าง",
        "ตำลึง",
        "ติด",
        "ตีน",
        "ตื่น",
        "ตู้",
        "ตู่",
        "เตา",
        "เตียน",
        "แต่ง",
        "แตะ",
        "แต่",
        "โตย",
        "โต",
        "ไต้หวัน",
        "ไต้",
        "ถกเถียง",
        "ถาง",
        "ถีบ",
        "ถึง",
        "แถบ",
        "ทด",
        "ทดลอง",
        "ทรัพย์สิน",
        "ทวด",
        "ทวิตเตอร์",
        "ทหาร",
        "ท้องฟ้า",
        "ทอด",
        "ทอดมัน",
        "ทั่ว",
        "ทาน",
        "ทำสวน",
        "ที่ดิน",
        "ที่",
        "ทุกข์",
        "ทุ่ม",
        "เทเลแกรม",
        "แท็กซี่",
        "แท็บลอยด์",
        "ธนาคาร",
        "ธาตุ",
        "น้อง",
        "นักเรียน",
        "นั่ง",
        "น้า",
        "น้ำเย็น",
        "น้ำหวาน",
        "นิ่ม",
        "นุ่น",
        "เนื่องจาก",
        "เนื้อ",
        "โน่น",
        "ใน",
        "บริโภค",
        "บริษัท",
        "บอก",
        "บอกใบ้",
        "บัดนี้",
        "บันได",
        "บาด",
        "บูชา",
        "บูด",
        "เบียร์",
        "ใบไม้",
        "ปกครอง",
        "ประชาธิปไตย",
        "ประพฤติ",
        "ประสบการณ์",
        "ปาก",
        "ปิ่นโต",
        "ปี",
        "ปี่",
        "ปู",
        "เป็น",
        "เปลือง",
        "เป้า",
        "แปรง",
        "ผล",
        "ผลัด",
        "ผลิต",
        "ผสม",
        "ผ่อ",
        "ผัก",
        "ผิด",
        "ผีก",
        "ผู้ร้าย",
        "เผื่อ",
        "แผนที่",
        "โผล่",
        "ฝาก",
        "พนมมือ",
        "พยาธิ",
        "พ่อ",
        "พักผ่อน",
        "พับ",
        "พิการ",
        "พิพักพิพ่วน",
        "เพดาน",
        "เพราะ",
        "เพลง",
        "เพียง",
        "แพ้",
        "ฟาก",
        "เฟซบุ๊ก",
        "มลายู",
        "มอบ",
        "มะเขือเทศ",
        "มัสยิด",
        "มิตร",
        "เมตตา",
        "เมล็ด",
        "เมาะ",
        "แมค",
        "แม่มด",
        "แมลง",
        "แม่",
        "แม้",
        "ย่อ",
        "ยัน",
        "ยา",
        "ย้ำ",
        "ยีราฟ",
        "ยึด",
        "ยูทูบ",
        "เย็น",
        "เย็บ",
        "เยอะ",
        "เยาวชน",
        "รถโดยสาร",
        "รถถัง",
        "รถทัวร์",
        "รถบัส",
        "ร่มรื่น",
        "รสชาติ",
        "ร้อน",
        "รอ",
        "ระเบียง",
        "ระยำ",
        "รังแก",
        "รัฐบาล",
        "รัฐประหาร",
        "ราก",
        "ร่างกาย",
        "ร่าง",
        "ริม",
        "รู้จัก",
        "เริ่ม",
        "เรียง",
        "เรื่อย",
        "แรก",
        "แรงงาน",
        "โรงสี",
        "ฤดู",
        "ลงมือ",
        "ล่อ",
        "ลืมคาว",
        "ลูกชิ้น",
        "ลูกตา",
        "ลูก",
        "เล่ม",
        "เลี้ยว",
        "เลือก",
        "แลก",
        "และ",
        "วัง",
        "วัฒนธรรม",
        "วาด",
        "วิกิพีเดีย",
        "วิ่ง",
        "วิชาชีพ",
        "วินโดวส์",
        "ศาลากลาง",
        "ศาสตร์",
        "ศิษย์",
        "เศรษฐกิจ",
        "เศษอาหาร",
        "เศษ",
        "สดชื่น",
        "สด",
        "สถานี",
        "สนอง",
        "สบาย",
        "สมอง",
        "สมาคม",
        "สม่ำเสมอ",
        "สลับ",
        "สหกรณ์",
        "สหภาพ",
        "สัญญา",
        "สาธารณรัฐ",
        "สารวัตร",
        "สำนักงาน",
        "สำหรับ",
        "สีแดง",
        "สีเทา",
        "สี",
        "สุขภาพ",
        "สุดท้าย",
        "เสรีนิยม",
        "เสรีภาพ",
        "เสียบ",
        "แสง",
        "หน้ากาก",
        "หน้าต่าง",
        "หน้าที่",
        "หนุน",
        "หนู",
        "หมด",
        "ห่มผ้า",
        "หมอก",
        "หม้อ",
        "หมัด",
        "หมี",
        "หมุน",
        "หยอก",
        "หยัก",
        "หรือ",
        "หลง",
        "หล่น",
        "หลบ",
        "หลังคา",
        "ห่วงใย",
        "หว่าน",
        "ห่อข้าว",
        "ห้องเรียน",
        "หอย",
        "ห้าง",
        "หาบ",
        "หาม้าย",
        "หาย",
        "หึงสา",
        "หุ้ม",
        "เหตุ",
        "เห็น",
        "แหย่",
        "ใหม่",
        "ไหน",
        "องค์",
        "อด",
        "อธิษฐาน",
        "อนุบาล",
        "อบอุ่น",
        "อวัยวะ",
        "ออนซอนเด๊",
        "อ่อนหวาน",
        "อัศจรรย์",
        "อายุ",
        "อาสา",
        "อาหาร",
        "อิฐ",
        "อินเทอร์เน็ต",
        "อินสตาแกรม",
        "อิสลาม",
        "อุปโภค",
        "เอสซีบี",
        "เอิด",
        "แอนดรอยด์",
        "ไอศกรีม",
        "ไอโอเอส",
    )



from .. import Provider as LoremProvider


class Provider(LoremProvider):
    """Implement lorem provider for ``hy_AM`` locale.

    Sources:

    - https://www.101languages.net/armenian/armenian-word-list
    """

    word_list = (
        "ես",
        "դու",
        "նա",
        "մենք",
        "դուք",
        "նրանք",
        "այս",
        "այն",
        "այստեղ",
        "այնտեղ",
        "ով",
        "ինչ",
        "որտեղ",
        "ուր",
        "երբ",
        "ինչպես",
        "ոչ",
        "բոլոր",
        "շատ",
        "որոշ",
        "քիչ",
        "այլ",
        "ուրիշ",
        "մեկ",
        "երկու",
        "երեք",
        "չորս",
        "հինգ",
        "մեծ",
        "երկար",
        "լայն",
        "հաստ",
        "ծանր",
        "փոքր",
        "կարճ",
        "նեղ",
        "բարակ",
        "կին",
        "տղամարդ",
        "մարդ",
        "երեխա",
        "կին",
        "ամուսին",
        "մայր",
        "հայր",
        "կենդանի",
        "ձուկ",
        "թռչուն",
        "շուն",
        "ոջիլ",
        "օձ",
        "ճիճու",
        "ծառ",
        "անտառ",
        "փայտ",
        "պտուղ",
        "սերմ",
        "տերև",
        "արմատ",
        "կեղև",
        "ծաղիկ",
        "խոտ",
        "պարան",
        "մաշկ",
        "կաշի",
        "միս",
        "արյուն",
        "ոսկոր",
        "ճարպ",
        "ձու",
        "եղջյուր",
        "պոզ",
        "պոչ",
        "փետուր",
        "մազ",
        "գլուխ",
        "ականջ",
        "աչք",
        "քիթ",
        "բերան",
        "ատամ",
        "լեզու",
        "եղունգ",
        "ոտք",
        "ծունկ",
        "ձեռք",
        "թև",
        "փոր",
        "փորոտիք",
        "աղիք",
        "վիզ",
        "մեջք",
        "կուրծք",
        "սիրտ",
        "լյարդ",
        "խմել",
        "ուտել",
        "կծել",
        "ծծել",
        "թքել",
        "ործկալ",
        "փչել",
        "շնչել",
        "ծիծաղել",
        "տեսնել",
        "լսել",
        "իմանալ",
        "գիտենալ",
        "մտածել",
        "զգալ",
        "վախենալ",
        "քնել",
        "ապրել",
        "մեռնել",
        "սպանել",
        "կռվել",
        "որսալ",
        "խփել",
        "հարվածել",
        "կտրել",
        "բաժանել",
        "խոցել",
        "քերծել",
        "քորել",
        "փորել",
        "լողալ",
        "թռչել",
        "քայլել",
        "գալ",
        "պառկել",
        "նստել",
        "կանգնել",
        "շրջվել",
        "ընկնել",
        "տալ",
        "պահել",
        "բռնել",
        "սեղմել",
        "շփել",
        "լվալ",
        "սրբել",
        "ձգել",
        "քաշել",
        "հրել",
        "նետել",
        "կապել",
        "կարել",
        "հաշվել",
        "ասել",
        "երգել",
        "խաղալ",
        "լողալ",
        "հոսել",
        "սառչել",
        "ուռել",
        "արև",
        "լուսին",
        "աստղ",
        "ջուր",
        "անձրև",
        "գետ",
        "լիճ",
        "ծով",
        "աղ",
        "քար",
        "ավազ",
        "փոշի",
        "հող",
        "ամպ",
        "մառախուղ",
        "մշուշ",
        "երկինք",
        "քամի",
        "ձյուն",
        "սառույց",
        "ծուխ",
        "հուր",
        "կրակ",
        "մոխիր",
        "վառվել",
        "այրվել",
        "ճամփա",
        "ճանապարհ",
        "լեռ",
        "սար",
        "կարմիր",
        "կանաչ",
        "դեղին",
        "սպիտակ",
        "սև",
        "գիշեր",
        "օր",
        "տարի",
        "տաք",
        "ցուրտ",
        "լիքը",
        "նոր",
        "հին",
        "լավ",
        "վատ",
        "փտած",
        "կեղտոտ",
        "ուղիղ",
        "կլոր",
        "սուր",
        "բութ",
        "հարթ",
        "թաց",
        "չոր",
        "ճիշտ",
        "մոտ",
        "հեռու",
        "աջ",
    )



from collections import OrderedDict

from .. import Provider as ColorProvider

localized = True


class Provider(ColorProvider):
    """Implement color provider for ``pt_BR`` locale."""

    all_colors = OrderedDict(
        (
            ("Açafrão", "#F4C430"),
            ("Água-marinha média", "#66CDAA"),
            ("Água-marinha", "#7FFFD4"),
            ("Água", "#00FFFF"),
            ("Alizarina", "#E32636"),
            ("Amarelo brasilis", "#ECDB00"),
            ("Amarelo claro", "#FFFFE0"),
            ("Amarelo creme", "#ECD690"),
            ("Amarelo escuro", "#F2B73F"),
            ("Amarelo esverdeado", "#9ACD32"),
            ("Amarelo esverdeado", "#ADFF2F"),
            ("Amarelo ouro claro", "#FAFAD2"),
            ("Amarelo queimado", "#EEAD2D"),
            ("Amarelo", "#FFFF00"),
            ("Âmbar", "#FFBF00"),
            ("Ameixa", "#DDA0DD"),
            ("Amêndoa", "#FFEBCD"),
            ("Ametista", "#9966CC"),
            ("Aspargo", "#7BA05B"),
            ("Azul aço claro", "#B0C4DE"),
            ("Azul aço", "#4682B4"),
            ("Azul alice", "#F0F8FF"),
            ("Azul ardósia claro", "#8470FF"),
            ("Azul ardósia escuro", "#483D8B"),
            ("Azul ardósia médio", "#7B68EE"),
            ("Azul ardósia", "#6A5ACD"),
            ("Azul areado", "#B8CAD4"),
            ("Azul brasilis brilhante", "#09ACDB"),
            ("Azul brasilis", "#00BDCE"),
            ("Azul cadete", "#5F9EA0"),
            ("Azul camarada", "#054F77"),
            ("Azul celeste brilhante", "#007FFF"),
            ("Azul celeste pernambucano", "#00A4CD"),
            ("Azul celeste", "#F0FFFF"),
            ("Azul céu claro", "#87CEFA"),
            ("Azul céu profundo", "#00BFFF"),
            ("Azul céu", "#87CEEB"),
            ("Azul claro", "#ADD8E6"),
            ("Azul cobalto", "#0047AB"),
            ("Azul escuro", "#00008B"),
            ("Azul flor de milho", "#6495ED"),
            ("Azul força aérea", "#5D8AA8"),
            ("Azul furtivo", "#1E90FF"),
            ("Azul manteiga", "#A6AA3E"),
            ("Azul marinho", "#120A8F"),
            ("Azul médio", "#0000CD"),
            ("Azul meia-noite", "#191970"),
            ("Azul petróleo", "#084D6E"),
            ("Azul pólvora", "#B0E0E6"),
            ("Azul real", "#0000DD"),
            ("Azul taparuere", "#248EFF"),
            ("Azul turquesa brilhante", "#00DDFF"),
            ("Azul turquesa", "#00CCEE"),
            ("Azul violeta", "#8A2BE2"),
            ("Azul", "#0000FF"),
            ("Bege", "#F5F5DC"),
            ("Bordô", "#800000"),
            ("Borgonha", "#900020"),
            ("Branco antigo", "#FAEBD7"),
            ("Branco fantasma", "#F8F8FF"),
            ("Branco floral", "#FFFAF0"),
            ("Branco fumaça", "#F5F5F5"),
            ("Branco navajo", "#FFDEAD"),
            ("Branco", "#FFFFFF"),
            ("Brasil", "#A7F432"),
            ("Bronze", "#CD7F32"),
            ("Caqui escuro", "#BDB76B"),
            ("Caqui", "#F0E68C"),
            ("Caramelo", "#8B5742"),
            ("Cardo", "#D8BFD8"),
            ("Carmesim", "#DC143C"),
            ("Carmim carnáceo", "#960018"),
            ("Carmim clássico", "#992244"),
            ("Carmim", "#712F26"),
            ("Castanho avermelhado", "#8B0000"),
            ("Castanho claro", "#D2B48C"),
            ("Cenoura", "#ED9121"),
            ("Cereja Hollywood", "#F400A1"),
            ("Cereja", "#DE3163"),
            ("Chocolate", "#D2691E"),
            ("Ciano claro", "#E0FFFF"),
            ("Ciano escuro", "#008B8B"),
            ("Ciano", "#00FFFF"),
            ("Cinza ardósia claro", "#778899"),
            ("Cinza ardósia escuro", "#2F4F4F"),
            ("Cinza ardósia", "#708090"),
            ("Cinza claro", "#D3D3D3"),
            ("Cinza escuro", "#A9A9A9"),
            ("Cinza fosco", "#696969"),
            ("Cinza médio", "#DCDCDC"),
            ("Cinza", "#808080"),
            ("Cobre", "#B87333"),
            ("Concha", "#FFF5EE"),
            ("Coral claro", "#F08080"),
            ("Coral", "#FF7F50"),
            ("Couro", "#F0DC82"),
            ("Creme de marisco", "#FFE4C4"),
            ("Creme de menta", "#F5FFFA"),
            ("Creme", "#FFFDD0"),
            ("Dourado escuro", "#B8860B"),
            ("Dourado pálido", "#EEE8AA"),
            ("Dourado", "#DAA520"),
            ("Ébano", "#555D50"),
            ("Eminência", "#6C3082"),
            ("Escarlate", "#FF2400"),
            ("Esmeralda", "#50C878"),
            ("Eucalipto", "#44D7A8"),
            ("Fandango", "#B53389"),
            ("Feldspato", "#FDD5B1"),
            ("Ferrugem", "#B7410E"),
            ("Flerte", "#A2006D"),
            ("Fúcsia", "#FF00FF"),
            ("Fuligem", "#3D2B1F"),
            ("Glicínia", "#C9A0DC"),
            ("Glitter", "#E6E8FA"),
            ("Grená", "#831D1C"),
            ("Heliotrópio", "#DF73FF"),
            ("Herbal", "#2E8B57"),
            ("Independência", "#4C516D"),
            ("Índigo", "#4B0082"),
            ("Iris", "#5A4FCF"),
            ("Jade", "#00A86B"),
            ("Jambo", "#FF4500"),
            ("Jasmine", "#F8DE7E"),
            ("Kiwi", "#8EE53F"),
            ("Laranja claro", "#FFB84D"),
            ("Laranja escuro", "#FF8C00"),
            ("Laranja", "#FFA500"),
            ("Lavanda avermelhada", "#FFF0F5"),
            ("Lavanda", "#E6E6FA"),
            ("Lilás", "#C8A2C8"),
            ("Lima", "#FDE910"),
            ("Limão", "#00FF00"),
            ("Linho", "#FAF0E6"),
            ("Madeira", "#DEB887"),
            ("Magenta escuro", "#8B008B"),
            ("Magenta", "#FF00FF"),
            ("Malva", "#E0B0FF"),
            ("Mamão batido", "#FFEFD5"),
            ("Maná", "#F0FFF0"),
            ("Marfim", "#FFFFF0"),
            ("Marrom amarelado", "#F4A460"),
            ("Marrom claro", "#A52A2A"),
            ("Marrom rosado", "#BC8F8F"),
            ("Marrom sela", "#8B4513"),
            ("Marrom", "#964B00"),
            ("Milho Claro", "#FFF8DC"),
            ("Milho", "#FBEC5D"),
            ("Mocassim", "#FFE4B5"),
            ("Mostarda", "#FFDB58"),
            ("Naval", "#000080"),
            ("Neve", "#FFFAFA"),
            ("Nyanza", "#E9FFDB"),
            ("Ocre", "#CC7722"),
            ("Oliva escura", "#556B2F"),
            ("Oliva parda", "#6B8E23"),
            ("Oliva", "#808000"),
            ("Orquídea escura", "#9932CC"),
            ("Orquídea média", "#BA55D3"),
            ("Orquídea", "#DA70D6"),
            ("Ouro", "#FFD700"),
            ("Pardo escuro", "#CC6600"),
            ("Pardo", "#CD853F"),
            ("Pêssego", "#FFDAB9"),
            ("Prata", "#C0C0C0"),
            ("Preto", "#000000"),
            ("Púrpura média", "#9370DB"),
            ("Púrpura", "#800080"),
            ("Quantum", "#111111"),
            ("Quartzo", "#51484F"),
            ("Renda antiga", "#FDF5E6"),
            ("Rosa amoroso", "#CD69CD"),
            ("Rosa brilhante", "#FF007F"),
            ("Rosa Choque", "#FC0FC0"),
            ("Rosa claro", "#FFB6C1"),
            ("Rosa danação", "#DA69A1"),
            ("Rosa embaçado", "#FFE4E1"),
            ("Rosa forte", "#FF69B4"),
            ("Rosa profundo", "#FF1493"),
            ("Rosa", "#FFCBDB"),
            ("Roxo brasilis", "#8A008A"),
            ("Roxo", "#993399"),
            ("Rútilo", "#6D351A"),
            ("Salmão claro", "#FFA07A"),
            ("Salmão escuro", "#E9967A"),
            ("Salmão", "#FA7F72"),
            ("Sépia", "#705714"),
            ("Siena", "#FF8247"),
            ("Tangerina", "#F28500"),
            ("Terracota", "#E2725B"),
            ("Tijolo refratário", "#B22222"),
            ("Tomate", "#FF6347"),
            ("Triássico", "#FF2401"),
            ("Trigo", "#F5DEB3"),
            ("Turquesa escura", "#00CED1"),
            ("Turquesa média", "#48D1CC"),
            ("Turquesa pálida", "#AFEEEE"),
            ("Turquesa", "#40E0D0"),
            ("Urucum", "#EC2300"),
            ("Verde amarelado", "#9ACD32"),
            ("Verde claro", "#90EE90"),
            ("Verde escuro", "#006400"),
            ("Verde espectro", "#00FF00"),
            ("Verde floresta", "#228B22"),
            ("Verde fluorescente", "#CCFF33"),
            ("Verde grama", "#7CFC00"),
            ("Verde lima", "#32CD32"),
            ("Verde mar claro", "#20B2AA"),
            ("Verde mar escuro", "#8FBC8F"),
            ("Verde mar médio", "#3CB371"),
            ("Verde militar", "#78866B"),
            ("Verde pálido", "#98FB98"),
            ("Verde Paris", "#7FFF00"),
            ("Verde primavera médio", "#00FA9A"),
            ("Verde primavera", "#00FF7F"),
            ("Verde-azulado", "#008080"),
            ("Verde", "#008000"),
            ("Vermelho enegrecido", "#550000"),
            ("Vermelho escuro", "#8B0000"),
            ("Vermelho indiano", "#CD5C5C"),
            ("Vermelho violeta médio", "#C71585"),
            ("Vermelho violeta pálido", "#DB7093"),
            ("Vermelho violeta", "#D02090"),
            ("Vermelho", "#FF0000"),
            ("Violeta claro", "#F8CBF8"),
            ("Violeta escuro", "#9400D3"),
            ("Violeta", "#EE82EE"),
            ("Zinco", "#E2DDF0"),
        )
    )

    safe_colors = (
        "preto",
        "marrom",
        "verde",
        "azul escuro",
        "verde escuro",
        "roxo",
        "laranja",
        "verde claro",
        "azul",
        "rosa",
        "violeta",
        "cinza",
        "amarelo",
        "magenta",
        "ciano",
        "branco",
    )



from collections import OrderedDict

from ..en import Provider as AddressProvider


class Provider(AddressProvider):
    counties = (
        "Cork",
        "Galway",
        "Mayo",
        "Donegal",
        "Kerry",
        "Tipperary",
        "Clare",
        "Tyrone",
        "Antrim",
        "Limerick",
        "Roscommon",
        "Down",
        "Meath",
        "Londonderry",
        "Wexford",
        "Kilkenny",
        "Offaly",
        "Cavan",
        "Wicklow",
        "Waterford",
        "Sligo",
        "Laois",
        "Westmeath",
        "Kildare",
        "Leitrim",
        "Armagh",
        "Fermanagh",
        "Monaghan",
        "Dublin",
        "Louth",
        "Longford",
        "Carlow",
    )

    _postcode_sets = OrderedDict(
        (
            (" ", [" ", ""]),
            ("N", [str(i) for i in range(0, 10)]),
            ("L", "ACDEFHKNPRTVWXY"),
            ("A", "ACDEFHKNPRTVWXY0123456789"),
        )
    )
    postcode_pattern: str = "LNN AAAA"

    def postcode(self) -> str:
        postcode = ""
        for placeholder in self.postcode_pattern:
            postcode += self.random_element(self._postcode_sets[placeholder])
        return postcode

    def administrative_unit(self) -> str:
        return self.random_element(self.counties)

    county = administrative_unit



from .. import Provider as InternetProvider


class Provider(InternetProvider):
    safe_email_tlds = ("com", "net", "eu", "it", "it", "it")
    free_email_domains = (
        "libero.it",
        "libero.it",
        "libero.it",
        "tim.it",
        "tin.it",
        "alice.it",
        "virgilio.it",
        "tiscali.it",
        "fastwebnet.it",
        "vodafone.it",
        "poste.it",
        "gmail.com",
        "gmail.com",
        "gmail.com",
        "outlook.com",
        "live.com",
        "hotmail.com",
        "hotmail.it",
        "yahoo.com",
        "tele2.it",
    )
    tlds = ("com", "com", "com", "net", "org", "eu", "it", "it", "it", "it")
    replacements = (
        ("à", "a"),
        ("é", "e"),
        ("è", "e"),
        ("ì", "i"),
        ("ò", "o"),
        ("ù", "u"),
    )



from .. import Provider as AddressProvider


class Provider(AddressProvider):
    city_formats = ("{{city_name}}",)
    street_name_formats = ("{{street_title}}",)
    street_address_formats = ("{{street_name}} {{building_number}}",)
    address_formats = ("{{street_address}}, {{city}}, {{postcode}}",)
    postcode_formats = ("#######",)

    # Data sourced from data.gov.il
    # https://data.gov.il/dataset/321

    street_titles = (
        "אביב",
        "אביגיל",
        "אבן מסעוד",
        "אברבנאל",
        "אברהם ברזילי",
        "אגוז",
        "אדמון",
        "אהרון מאיר מזיא",
        "אהרונוביץ",
        "אולפן",
        "אורנים",
        "אזור בית הקברות",
        "אזור תעשיה א'",
        "אזור תעשיה הר יונה",
        "אזור תעשייה",
        "אזור תעשייה מזרח",
        'אח"י אילת',
        "אייזיק ניוטון",
        "איילת השחר )מ ק(",
        "אייר",
        "אילניה",
        "אימבר",
        "אירוס",
        "אירוס",
        "אל הודא סמ3",
        "אלוורוד",
        "אלול",
        "אלומה",
        "אלזאבוד",
        "אל-זהרא'",
        "אל זיתון סמ2",
        "אלזיתונה סמ7",
        "אל חגאג בן יוסף",
        "אל-חראיק סמ3",
        "אלחרש",
        "אל-ט'הרה סמ7",
        "אלישר",
        "אלכנסת",
        "אלכסנדר ינאי",
        "אלכרום",
        "אלכתאב",
        "אל-לימון",
        "אלמזדלפה",
        "אל-מחאג'ר סמ3",
        "אל-מחאג'ר סמ4",
        "אלמנשיה-מושירפה",
        "אל-מקפה סמ9",
        "אל-סביל סמ6",
        "אלסלילמה",
        "אלסריס",
        "אלעמשקה",
        "אלעקבה",
        "אל-פארוק סמ2",
        "אלפג'ר",
        "אלרשיד",
        "אלתין",
        "אלתרמן",
        "אסא המלך",
        "אפעל",
        "ארבל",
        "אשדוד",
        "אשל",
        "אתגר",
        "אתר חפץ חיים",
        "בועז",
        "בורסת היהלומים",
        "ביכורים",
        'ביל"ו',
        "בילינסון",
        "בית אבות",
        "בית היוצר",
        "בית יצחק-שער חפר",
        "בית ראשון במולדת",
        "בן יהודה",
        "בן ישי",
        "בן לברט",
        "בן צבי יצחק",
        "בן צבי יצחק",
        "בן צבי שמעון",
        "בקעת הירח",
        "ברגמן אליעזר",
        "ברוריה",
        "ברזיל",
        "ברקת",
        "בשמת",
        "בשמת",
        "גבע",
        "גבע",
        "גבעת חיים )מאוחד(",
        "גובר רבקה",
        "גוטמכר",
        "גולדה מאיר",
        "ג'ו עמר",
        "גיבתון חנוך",
        "גינוסר",
        "גפן",
        "גפן",
        "גרטרוד קראוס",
        "גרינבוים",
        "דבורה",
        "דודו דותן",
        "דולב",
        "דולצ'ין אריה",
        "דחי",
        "דיה",
        "דימיטר פשב",
        "דרב אלברג'",
        "דרומית-מג'ד אלכרום",
        "דריפוס",
        "דרך הארץ",
        "דרך הגן",
        "דרך חברון",
        "דרך חלמית",
        "דרך שועפאט סמ4",
        "האדמו\"ר מויז'ניץ",
        "האודם",
        "האורן",
        "האורנים",
        "האחים בז'רנו",
        "האילן",
        "האילנות",
        "האילתית",
        "האלונים",
        "האמוראים",
        "האצטדיון",
        'האצ"ל',
        "הברדלס",
        "הברוש",
        "הבריגדה",
        "הגבורה",
        "הגפן",
        "הגפן",
        "הדגניות",
        "הדולב",
        "הדייגים",
        "הדרך האמריקאית סמ12",
        "ההגנה",
        "ההגנה",
        "הולצברג שמחה",
        "הופרט יעקב",
        "הורדים",
        "הורקנוס יוחנן",
        "הזיתים",
        "הזמיר",
        "החבל",
        "החותרים",
        "החלוצים",
        "החליל",
        "החמנית",
        "החסידה",
        "החצב",
        "החצב",
        "החרוב",
        "החרובים",
        "החרמון",
        "החשמל",
        "היוזם",
        "הינשוף",
        "היקינטון",
        'הל"ה',
        "המאה ואחד",
        "המבריא",
        "המברק",
        "המגינים",
        "המגינים",
        "המורד",
        "המייסדים",
        "המלאכה",
        "המלאכה",
        "המלכים",
        "הממונה",
        "המנוע",
        "המסגר",
        "המעיין",
        "המפרש",
        "המצודה",
        "המרגנית",
        "המשור",
        "הנוטר",
        "הנורית",
        "הנורית",
        "הנקר",
        "הנרד",
        "הסיגלית",
        "הסיפון",
        "העבודה",
        "העבודה",
        "העצמון",
        "הפעמון",
        "הפרדס",
        "הפרדס",
        "הפרדס",
        "הפרדס",
        "הצאלון",
        "הצבעוני",
        "הקישון",
        "הראשונים",
        "הרב בידאני עובדיה",
        "הרב וולף",
        "הרב חכם שמעון",
        "הרבי מליובאוויטש",
        "הרב ניסים",
        "הרב עוזיאל",
        "הרב רפאל עבו",
        "הרדוף",
        "הרדוף",
        "הרדוף",
        "הרותם",
        "הרי גולן",
        "הר יהל",
        "הרימון",
        "הר כנען",
        "הרליץ יוסף",
        "הר סיני",
        "הר עצמון",
        "הר צרור",
        "הרקפת",
        "הרשקו אברהם",
        "הרשת",
        "השדות",
        "השחר",
        "השיזף",
        "השיח",
        "השיטה",
        "השעורה",
        "השר ברזילי",
        "התאנה",
        "התבור",
        "התקוה",
        "ויקטור ויוליוס",
        "וערת סעד",
        "ז'בוטינסקי",
        "זגגי",
        "זיגורד",
        "זיו",
        "ז'ילבר",
        "זית",
        "זכרון יעקב",
        "חוחית",
        "חוף הים",
        "חושן",
        "חזון איש",
        "חזן יעקב",
        "חיטה",
        "חיים וייצמן",
        "חלמיש",
        "חצב",
        "חרת א בוס",
        "חתוכה יורם",
        "טאבליא",
        "טאחונת אלראהיב",
        "טביב",
        "טופז",
        'י"א באדר',
        "יאפא",
        "יד העפלה ממרוקו",
        "ידידה",
        "יהודה הלוי",
        "יהודה המכבי",
        "יהודה המכבי",
        "יואב",
        "יונה",
        "יזרעאל",
        "יחזקאל הנביא",
        "יכין",
        "ירושלים",
        "ירקון",
        "ישועת דוד",
        "יששכר",
        "כאבול",
        "כהן אלי",
        "כהנא",
        "כוכב הצפון",
        "כזיב",
        "כיסופים",
        "ככר ירדן",
        "ככר נחשון",
        "כנרת",
        "כפר ילדים נרדים",
        "כרם חמד",
        "לב הקריה",
        "לביא אריק",
        "לבקוביץ",
        "לוד הצעירה",
        "לוטם",
        "לוין מיכאל וחנה",
        "לוין שמריהו",
        "לוריא",
        'לח"י',
        "לילינבלום",
        "לכיש",
        "לסקוב חיים",
        "מבוא הדס",
        "מבוא הזיתים",
        "מבוא חיים מקובנה",
        "מבוא חמה",
        "מבצע הראל",
        "מבצע חירם",
        "מבצע עובדה",
        "מגלן",
        "מוסיוף שלמה",
        "מופק דיאב",
        "מוצא",
        "מורדי הגטאות",
        "מורן",
        "מזל שור",
        "מזרחי יוסף",
        "מיכה",
        "מירון",
        "מישאל",
        "מלון רויאל פארק",
        "מנזר המארונים",
        "מעבר לים",
        "מעוז חיים",
        "מעונות ים",
        "מעלה כגן הלנה",
        "מענית",
        "מצדה",
        "מצפה גילה",
        "מרגיל מחוור",
        "מרווה",
        "מרחביה )מושב(",
        "מרכז",
        "משה דיין",
        "משואות יצחק",
        "משעול אבוקדו",
        "משעול האלה",
        "משעול המחתרות",
        "משעול הסיפן",
        "משעול הצופית",
        "משעול התפוח",
        "משעול מוריה",
        "משעול נקר",
        "משעול פארן",
        "נאות אביבים",
        "נאות אשכול",
        "נאות הדקל",
        "נדב יצחק",
        "נהריה",
        "נוה עוז",
        "נוף כנרת",
        "נורית",
        "נחל נחשון",
        "נחל סרפד",
        'נחל ערוגות מ"ר',
        "נחל פארן",
        "נחלת צדוק",
        "ניר עם",
        'נעמ"ת',
        "נצרת עילית",
        "נשר",
        "נתיב הפורצים",
        "נתן",
        "סביונים מכבים רעות",
        "סומך עובדיה",
        "סיתוונית",
        "סלא איירין",
        "סלעית",
        "סמ 20 20",
        "סמבורסקי דניאל",
        "סמ בני ברית",
        "סמ הבוסתן",
        "סמ הרכבת",
        "סמ השחף",
        "סמטת השחר",
        "סמ מאלה",
        "סמ מסילה א",
        "סמ עין גנים",
        "סמ עינב",
        "סמ שפיפון",
        "סנט הלנה",
        "עבד אל-גני",
        "עגור",
        "ע הלל",
        "עובדי הנמל",
        "עוגן",
        "עולש מצוי",
        "עומר",
        "עידו הנביא",
        "עין שביב",
        "עירית",
        "עמוס",
        "עמוס הנביא",
        "עמנואל )רינגלבלום(",
        "ענזה",
        "עפולה",
        "עקבת א תות",
        "פדויים",
        "פטדה",
        "פנינה",
        "פקוד מרכז",
        "פרומקין גד",
        "פרופ' בירק יהודית",
        "פרופס",
        "פרי חדש",
        "צדוק הכהן",
        "צובה",
        "צופית",
        "צוקית",
        "צור",
        "צמחי היהודים",
        "צפרירים",
        "צפת",
        "צפת",
        "קבועה )שבט(",
        "קדמת צבי",
        "קישון אפרים",
        "קנין הארץ",
        "קרית עקרון",
        "קרל נטר",
        "קרן היסוד",
        "רביבים",
        "רבנו תם",
        "רבקה אמנו",
        "רח 101",
        "רח 1043",
        "רח 1060",
        "רח 12",
        "רח 1238",
        "רח 124",
        "רח 135",
        "רח 14",
        "רח 16",
        "רח 16",
        "רח 2001",
        "רח 2306",
        "רח 5041",
        "רח 6020",
        "רח 6073",
        "רח 6087",
        "רח 68",
        "רח 7035",
        "רח 7038",
        "רח 7069",
        "רח 71",
        "רחבת פנינה",
        "רח ה",
        "רח מו כ שלם",
        "רח רז",
        "ריחאניה",
        'רלב"ג',
        'רמב"ם',
        'רמב"ן',
        "רמת האירוסים",
        "רמת כרמים",
        "רקפת",
        'רש"י',
        "ש אסבסטונים",
        "ש אסבסט צפון",
        "שאר ישוב",
        "ש בבלי",
        "שבזי",
        "שבזי",
        "שבטי ישראל",
        "שבט ראובן",
        "שביל הרקפות",
        "שביל קליפות התפוזים",
        "שד גאולים",
        "שד גת",
        "שד העצמאות",
        'שד ח"ן',
        "שד יוספטל גיורא",
        "ש הפועלים",
        "שוהם",
        "שומרון",
        "שושנה דמארי",
        "שושנת הכרמל",
        'שז"ר זלמן',
        "שיזף",
        "שכ 14",
        "שכ החלוצים",
        "שכ היובל",
        "שכ הפועל המזרחי ג'",
        "שכ הרכבת",
        "שכ זאב",
        "שכ חפצי בה",
        "שכ מחניים",
        "שכ נווה הדקל",
        "שכ עראק אלשבאב",
        "שכ קחאוש",
        "שכ רסקו",
        "שלדג",
        "שמחוני",
        "שמחוני אסף",
        "שמעון המכבי",
        "שני",
        "ש סלע חדש",
        "ש פועלים",
        'ש"ץ גרשון',
        "ש ציונים כלליים",
        "שקד",
        "ש קואפרטיבים",
        "שריג",
        "ש רמת אביב",
        "תאנה",
        "תל חי",
        "תפארת ישראל",
        'תרס"ח',
        'תרצ"ו',
    )

    city_names = (
        "אבו רובייעה )שבט(",
        "אביבים",
        "אביחיל",
        "אודם",
        "אור הנר",
        "אורטל",
        "אטרש )שבט(",
        "אליקים",
        "אל סייד",
        "באר מילכה",
        "בית ברל",
        "בית הלוי",
        "בית חנן",
        "בית חנניה",
        "בית חשמונאי",
        "בני ציון",
        "ברקאי",
        "ברקת",
        "גבעת השלושה",
        'גבעת ח"ן',
        'גבעת כ"ח',
        "גדות",
        "גונן",
        "גינתון",
        "גיתית",
        "גן שורק",
        "גנות הדר",
        "גני מודיעין",
        "גרופית",
        'דוב"ב',
        "דולב",
        "האון",
        "הסוללים",
        "העוגן",
        "הר אדר",
        "ורד יריחו",
        "זוהר",
        "חיננית",
        "חצור-אשדוד",
        "חצור הגלילית",
        "חשמונאים",
        "טל-אל",
        'יד רמב"ם',
        "כסלון",
        "כפר אחים",
        "כפר הנוער הדתי",
        "כפר יונה",
        "כפר מסריק",
        "כפר סירקין",
        "לוזית",
        "לקיה",
        "מגאר",
        "מגן",
        "מזכרת בתיה",
        "מירון",
        "מכמורת",
        "מלאה",
        "מסד",
        "מעונה",
        "מרחביה )מושב(",
        "משמר העמק",
        "נווה חריף",
        "נוקדים",
        "נורדיה",
        "נחלה",
        "נטע",
        "נירן",
        "נתיב השיירה",
        "סגולה",
        "סער",
        "עדי",
        "עזר",
        "עין אל-אסד",
        "עין השופט",
        "עין צורים",
        "עלי זהב",
        "עמוקה",
        "עמיר",
        "עמקה",
        "עספיא",
        "עצמון שגב",
        "פוריה - נווה עובד",
        "פוריידיס",
        "פקיעין חדשה",
        "צורית",
        "צפרירים",
        "רגבה",
        "רחוב",
        "ריינה",
        "רימונים",
        "רמות מנשה",
        "שדה אליהו",
        "שדות מיכה",
        "שדי תרומות",
        "שומרה",
        "שיטים",
        "שעב",
        "שפר",
        "שתולים",
        "תלמי אליהו",
    )

    def city_name(self) -> str:
        return self.random_element(self.city_names)

    def street_title(self) -> str:
        return self.random_element(self.street_titles)
